
##------------------------------------------------------------------------------------------------------------------------------------------------
## Angelova 2018 Chapter 3: Coalition Conflict - a Remedy for Democratic Accountability
## All analyses, simulations, tables, and figures were created on OS 10.13.6 (High Sierra) using R version 3.5.0 (2018-04-23) and Zelig version Zelig 5.1.6 (note that newer and older versions of Zelig use different syntax)
##------------------------------------------------------------------------------------------------------------------------------------------------

##@@@------------------------------------------------------------------------------------------------------------------------------------------------
## Replication file 1: use this script to create the data used for all analyses, tables and figures
## All analyses are based on survey data from wave 1, 2, and 3 from the German Internet Panel (GIP), which is provided by GESIS. To download the data please follow the instructions here: http://reforms.uni-mannheim.de/internet_panel/Data%20access/. Some payment might apply depending on the number of waves you need and your status (up to 30 Euros for up to 5 waves). (More information on the charges can be found here: http://www.gesis.org/fileadmin/upload/dienstleistung/daten/umfragedaten/_bgordnung_bestellen/Charges.pdf ) 
## Note: check other replication files to replicate the analyses, tables, figures and footnotes reported in Chapter 3
## For further information please contact Mariyana Angelova: mariyana.angelova@univie.ac.at  OR mariyana.angelova@gmail.com
## October 2018
##@@@------------------------------------------------------------------------------------------------------------------------------------------------

## clean working space
	rm(list = ls(all = TRUE))

## load required packages
	library('foreign')
	library(haven) ##

## set working directory
		setwd("~/Documents/Dissertation/Diss - Replication - Chapter 3")

## load wave 1 and 2 of the GIP survey data as provided by GESIS
	gip1<-read.dta(file="./gip_data/ZA5866_v1-0-0.dta")
	gip2<-read.dta(file="./gip_data/ZA5867_v1-0-0.dta")
	gip3<-read.dta(file="./gip_data/ZA5868_v1-0-0.dta")
	# identifier for gip1 and gip2
	gip1$gip1<-1; gip2$gip2<-1;  gip3$gip3<-1


## rename some variables

	names(gip1)[names(gip1)=="za_nr"]<-"za_nr_gip1"
	names(gip1)[names(gip1)=="version"]<-"version_gip1"
	names(gip1)[names(gip1)=="doi"]<-"doi_gip1"
	names(gip1)[names(gip1)=="id_g"]<-"id_g_gip1"
	names(gip1)[names(gip1)=="gender_12"]<-"gender_12_gip1"	
	names(gip1)[names(gip1)=="age_cat_12"]<-"age_cat_12_gip1"
	names(gip1)[names(gip1)=="educ_school_12"]<-"educ_school_12_gip1"
	names(gip1)[names(gip1)=="educ_job_12"]<-"educ_job_12_gip1"
	names(gip1)[names(gip1)=="state"]<-"state_gip1"
	names(gip1)[names(gip1)=="dDatum"]<-"dDatum_gip1"

	
	names(gip2)[names(gip2)=="za_nr"]<-"za_nr_gip2"
	names(gip2)[names(gip2)=="version"]<-"version_gip2"
	names(gip2)[names(gip2)=="doi"]<-"doi_gip2"
	names(gip2)[names(gip2)=="id_g"]<-"id_g_gip2"
	names(gip2)[names(gip2)=="gender_12"]<-"gender_12_gip2"	
	names(gip2)[names(gip2)=="age_cat_12"]<-"age_cat_12_gip2"
	names(gip2)[names(gip2)=="educ_school_12"]<-"educ_school_12_gip2"
	names(gip2)[names(gip2)=="educ_job_12"]<-"educ_job_12_gip2"
	names(gip2)[names(gip2)=="marital_status_12"]<-"marital_status_12_gip2"
	names(gip2)[names(gip2)=="number_hh_members_12"]<-"number_hh_members_12_gip2"
	names(gip2)[names(gip2)=="occupation_12"]<-"occupation_12_gip2"	
	names(gip2)[names(gip2)=="state"]<-"state_gip2"
	names(gip2)[names(gip2)=="dDatum"]<-"dDatum_gip2"

	names(gip3)[names(gip3)=="za_nr"]<-"za_nr_gip3"
	names(gip3)[names(gip3)=="version"]<-"version_gip3"
	names(gip3)[names(gip3)=="doi"]<-"doi_gip3"
	names(gip3)[names(gip3)=="id_g"]<-"id_g_gip3"
	names(gip3)[names(gip3)=="gender_12"]<-"gender_12_gip3"	
	names(gip3)[names(gip3)=="age_cat_12"]<-"age_cat_12_gip3"
	names(gip3)[names(gip3)=="educ_school_12"]<-"educ_school_12_gip3"
	names(gip3)[names(gip3)=="educ_job_12"]<-"educ_job_12_gip3"
	names(gip3)[names(gip3)=="marital_status_12"]<-"marital_status_12_gip3"
	names(gip3)[names(gip3)=="number_hh_members_12"]<-"number_hh_members_12_gip3"
	names(gip3)[names(gip3)=="occupation_12"]<-"occupation_12_gip3"	
	names(gip3)[names(gip3)=="state"]<-"state_gip3"
	names(gip3)[names(gip3)=="dDatum"]<-"dDatum_gip3"





###### ------------------
## MERGE gip1 and gip2 and gip3 using hhid_g and pid variables
###### ------------------

	class(gip1$hhid_g)==class(gip2$hhid_g); id1<-unique(gip1$hhid_g); id2<-unique(gip2$hhid_g); length(intersect(id1,id2))==length(id2) # TRUE==number of unique ids in gip1 AND gip2 is the same as the number of ids in gip2
	class(gip1$hhid_g)==class(gip3$hhid_g); id1<-unique(gip1$hhid_g); id2<-unique(gip3$hhid_g); length(intersect(id1,id2))==length(id2) # TRUE==number of unique ids in gip1 AND gip2 is the same as the number of ids in gip2
	class(gip1$pid)==class(gip2$pid)
	class(gip1$pid)==class(gip3$pid)

	gip_1.2<-merge(x=gip1, y=gip2, by.x=c("hhid_g","pid"), by.y=c("hhid_g","pid"), all.x=TRUE, all.y=TRUE)
	gip<-merge(x= gip_1.2, y=gip3, by.x=c("hhid_g","pid"), by.y=c("hhid_g","pid"), all.x=TRUE, all.y=TRUE)

	## adjust identifyer for wave 2
	temp<-NA; temp<-gip
	gip$gip2[is.na(temp$gip2)]<-0
	gip$gip3[is.na(temp$gip3)]<-0
	dim(gip)
	names(gip)
	

	## GESIS provides only categories for age. If you do not have the dataset with the concrete age then assign the age category to the variable for age. 
	#	gip$age<-gip$age_cat
   # unique(gip[,c("age","age_cat")]



##------------------------------------------------------------------------------------------
## RENAME VARIABLES from GIP wave 1
##------------------------------------------------------------------------------------------
	
	gip$family_satisfaction <-gip$AA01023
	gip$leisure_satisfaction <-gip$AA01024
	gip$financial_satisfaction <-gip$AA01025
	gip$work_satisfaction <-gip$AA01026
	gip$social_activity_religion <-gip$AA01030
	gip$social_activity_civil_action <-gip$AA01032
	gip$vote_last_election <-gip$AA01038
	gip$voting_intention_gip1 <-gip$AA01039

	
	## left right ideology: a group got first l-r selfplacement and then party placement, b group got first party placement and then self placement
	
	gip$lr_selfplacement_a <-gip$AA01040a
	gip$lr_placement_cdu_a <-gip$AA01041a1
	gip$lr_placement_csu_a <-gip$AA01041a2
	gip$lr_placement_spd_a <-gip$AA01041a3
	gip$lr_placement_fdp_a <-gip$AA01041a4
	gip$lr_placement_greens_a <-gip$AA01041a5
	gip$lr_placement_linke_a <-gip$AA01041a6
	gip$lr_placement_npd_a <-gip$AA01041a7
	gip$lr_placement_pirates_a <-gip$AA01041a8
	
	
	gip$lr_selfplacement_b <-gip$AA01040b
	gip$lr_placement_cdu_b <-gip$AA01041b1
	gip$lr_placement_csu_b <-gip$AA01041b2
	gip$lr_placement_spd_b <-gip$AA01041b3
	gip$lr_placement_fdp_b <-gip$AA01041b4
	gip$lr_placement_greens_b <-gip$AA01041b5
	gip$lr_placement_linke_b <-gip$AA01041b6
	gip$lr_placement_npd_b <-gip$AA01041b7
	gip$lr_placement_pirates_b <-gip$AA01041b8

	
	## Party Identification
	
	gip$party_identification_dummy <-gip$AA01042 # 1- yes, 2-no
	gip$party_identification <-gip$AA01043
	gip$party_member <-gip$AA01035
		
		
	
	## GENDER
	names(gip)
	gip$gender_12 <-as.character(gip$gender_12_gip1)
	gip$woman<-NA
	gip$woman[gip$gender_12=="1. M\xe4nnlich"]<-0
	gip$woman[gip$gender_12=="2. Weiblich"]<-1
	table(gip$woman)
	

	## AGE: Note that in the article we used the original varibale for age which indicates the exact age. The exact age of the survey participants can not be provided for wide usage beacuse of personal data protection reasons. 
	gip$age_cat<-gip$age_cat_12_gip1
	gip$age_cat<-NA
	gip$age_cat[gip$age_cat_12_gip1 =="1. 16-19"]<-1
	gip$age_cat[gip$age_cat_12_gip1 =="2. 20-24"]<-2
	gip$age_cat[gip$age_cat_12_gip1 =="3. 25-29"]<-3
	gip$age_cat[gip$age_cat_12_gip1 =="4. 30-34"]<-4
	gip$age_cat[gip$age_cat_12_gip1 =="5. 35-39"]<-5
	gip$age_cat[gip$age_cat_12_gip1 =="6. 40-44"]<-6
	gip$age_cat[gip$age_cat_12_gip1 =="7. 45-49"]<-7
	gip$age_cat[gip$age_cat_12_gip1 =="8. 50-54"]<-8
	gip$age_cat[gip$age_cat_12_gip1 =="9. 55-59"]<-9
	gip$age_cat[gip$age_cat_12_gip1 =="10. 60-64"]<-10
	gip$age_cat[gip$age_cat_12_gip1 =="11. 65-69"]<-11
	gip$age_cat[gip$age_cat_12_gip1 =="12. 70-74"]<-12
	gip$age_cat[gip$age_cat_12_gip1 =="13. 75-79"]<-13
	gip$age_cat[gip$age_cat_12_gip1 =="-80. Wert nicht plausibel"]<-NA
	unique(gip$age_cat)


	gip$age_at_least <-gip$age_cat_12_gip1
	gip$age_at_least<-NA
	gip$age_at_least[gip$age_cat_12_gip1 =="1. 16-19"]<-16
	gip$age_at_least[gip$age_cat_12_gip1 =="2. 20-24"]<-20
	gip$age_at_least[gip$age_cat_12_gip1 =="3. 25-29"]<-25
	gip$age_at_least[gip$age_cat_12_gip1 =="4. 30-34"]<-30
	gip$age_at_least[gip$age_cat_12_gip1 =="5. 35-39"]<-35
	gip$age_at_least[gip$age_cat_12_gip1 =="6. 40-44"]<-40
	gip$age_at_least[gip$age_cat_12_gip1 =="7. 45-49"]<-45
	gip$age_at_least[gip$age_cat_12_gip1 =="8. 50-54"]<-50
	gip$age_at_least[gip$age_cat_12_gip1 =="9. 55-59"]<-55
	gip$age_at_least[gip$age_cat_12_gip1 =="10. 60-64"]<-60
	gip$age_at_least[gip$age_cat_12_gip1 =="11. 65-69"]<-65
	gip$age_at_least[gip$age_cat_12_gip1 =="12. 70-74"]<-70
	gip$age_at_least[gip$age_cat_12_gip1 =="13. 75-79"]<-75
	gip$age_at_least[gip$age_cat_12_gip1 =="-80. Wert nicht plausibel"]<-NA
	unique(gip$age_at_least)





	unique(gip[,c("age_cat","age_at_least","age_cat_12_gip1")])




	## EDUCATION (ordered)
	#unique(gip$educ_school_12)
	unique(gip$educ_job_12_gip1)
	gip$educ_job_12 <-as.character(gip$educ_job_12_gip1)
	gip$education<-NA
	gip$education[gip$educ_job_12 =="2. Sch\xfcler/-in und besuche eine berufsorientierte Aufbau-,  Fachschule o. \xe4."]<-1 # still in shool
	gip$education[gip$educ_job_12 =="3. Keinen beruflichen Abschluss und bin nicht in beruflicher Ausbildung"]<-2 # no professional qualification
	gip$education[gip$educ_job_12 =="5. Beruflich-schulische Ausbildung (Berufs-FH, Handelss., Vorber.-d. mittl. Dienst"]<-3 # school level professional qialification
	gip$education[gip$educ_job_12 =="4. Beruflich-betriebliche Berufsausbildung (Lehre) abgeschlossen"]<-4 # after school professional qualification - teacher
	gip$education[gip$educ_job_12 =="1. Noch in beruflicher Ausbildung (Berufsvorbereitungsjahr,  Auszubildende/r, Prakt"]<-5 # after school, intern, student
	gip$education[gip$educ_job_12 =="6. Ausbildung an einer Fachschule der DDR abgeschlossen"]<-6 #  (Ausbildung)
	gip$education[gip$educ_job_12 =="7. Ausbildung an einer Fach-, Meister-, Technikerschule, Berufs- oder Fachakademie"]<-6 #  (Ausbildung)
	gip$education[gip$educ_job_12 =="12. Einen anderen beruflichen Abschluss, und zwar (bitte eintragen)"]<-6 # other
	gip$education[gip$educ_job_12 =="8. Bachelor an (Fach-)Hochschule abgeschlossen"]<-7 # university level Bachelor
	gip$education[gip$educ_job_12 =="9. Fachhochschulabschluss (z. B. Diplom, Master)"]<-8 # university level Fachhochshule (Master)
	gip$education[gip$educ_job_12 =="10. Universit\xe4tsabschluss (z. B. Diplom, Magister, Staatsexamen, Master)"]<-8 # university level Universität (Master)
	gip$education[gip$educ_job_12 =="11. Promotion"]<-9 # Promotion
	gip$education[gip$educ_job_12 =="-90. item nonresponse"]<-NA
	table(gip$education, useNA="always")
	summary(gip$education)
	
	
		## EDUCATION (ordered like in GIP)
	#unique(gip$educ_school_12)
	unique(gip$educ_job_12_gip1)
	gip$educ_job_12 <-as.character(gip$educ_job_12_gip1)
	gip$education_12<-NA
	gip$education_12[gip$educ_job_12 =="1. Noch in beruflicher Ausbildung (Berufsvorbereitungsjahr,  Auszubildende/r, Prakt"]<-1 # after school, intern, student

	gip$education_12[gip$educ_job_12 =="2. Sch\xfcler/-in und besuche eine berufsorientierte Aufbau-,  Fachschule o. \xe4."]<-2 # still in shool
	gip$education_12[gip$educ_job_12 =="3. Keinen beruflichen Abschluss und bin nicht in beruflicher Ausbildung"]<-3 # no professional qualification
	gip$education_12[gip$educ_job_12 =="4. Beruflich-betriebliche Berufsausbildung (Lehre) abgeschlossen"]<-4 # after school professional qualification - teacher
	gip$education_12[gip$educ_job_12 =="5. Beruflich-schulische Ausbildung (Berufs-FH, Handelss., Vorber.-d. mittl. Dienst"]<-5 # school level professional qialification
	gip$education_12[gip$educ_job_12 =="6. Ausbildung an einer Fachschule der DDR abgeschlossen"]<-6 #  (Ausbildung)
	gip$education_12[gip$educ_job_12 =="7. Ausbildung an einer Fach-, Meister-, Technikerschule, Berufs- oder Fachakademie"]<-7 #  (Ausbildung)
	gip$education_12[gip$educ_job_12 =="8. Bachelor an (Fach-)Hochschule abgeschlossen"]<-8 # university level Bachelor
	gip$education_12[gip$educ_job_12 =="9. Fachhochschulabschluss (z. B. Diplom, Master)"]<-9 # university level Fachhochshule (Master)
	gip$education_12[gip$educ_job_12 =="10. Universit\xe4tsabschluss (z. B. Diplom, Magister, Staatsexamen, Master)"]<-10 # university level Universität (Master)
	gip$education_12[gip$educ_job_12 =="11. Promotion"]<-11 # Promotion
	gip$education_12[gip$educ_job_12 =="12. Einen anderen beruflichen Abschluss, und zwar (bitte eintragen)"]<-12 # other
	gip$education_12[gip$educ_job_12 =="-90. item nonresponse"]<-NA
	table(gip$education_12, useNA="always")
	summary(gip$education_12)
	
	
	
	
	
	
	
##------------------------------------------------------------------------------------------
## RENAME VARIABLES from GIP wave 1
##------------------------------------------------------------------------------------------



	## partisan and government ratings
	
	gip$satisfaction_gov <-gip$CE02001
	gip$satisfaction_party_cducsu <-gip$CE02002
	gip$satisfaction_party_spd <-gip$CE02003
	gip$satisfaction_party_fdp <-gip$CE02004
	gip$satisfaction_party_gruene <-gip$CE02005
	gip$satisfaction_party_linke <-gip$CE02006
	gip$n_no_answer_to_satisfaction_party <-gip$hf004

	
	## voting intention
	gip$voting_intention_gip2 <-gip$CE02008

	## government composition knowledge
	
	gip$polinfo_govparticipation_cducsu <-gip$CE02009
	gip$polinfo_govparticipation_spd <-gip$CE02010
	gip$polinfo_govparticipation_fdp <-gip$CE02011
	gip$polinfo_govparticipation_gruene <-gip$CE02012
	gip$polinfo_govparticipation_linke <-gip$CE02013



	## issue importance gov
	gip$issue_importance_gov_random_item_order_filter <-gip$hf008_filter
	gip$issue_importance_gov_random_item_order <-gip$hf008
	
	gip$issue_importance_gov_labormarket <-gip$CE02014
	gip$issue_importance_gov_foreignpolicy <-gip$CE02015
	gip$issue_importance_gov_education <-gip$CE02016
	gip$issue_importance_gov_participation <-gip$CE02017
	gip$issue_importance_gov_energy <-gip$CE02018
	
	gip$issue_importance_gov_eu <-gip$CE02019
	gip$issue_importance_gov_family <-gip$CE02020
	gip$issue_importance_gov_healthcare <-gip$CE02021
	gip$issue_importance_gov_equality <-gip$CE02022
	gip$issue_importance_gov_security <-gip$CE02023
	
	gip$issue_importance_gov_civilliberties <-gip$CE02024
	gip$issue_importance_gov_pension <-gip$CE02025
	gip$issue_importance_gov_debt <-gip$CE02026
	gip$issue_importance_gov_taxes <-gip$CE02027
	gip$issue_importance_gov_environment <-gip$CE02028
	
	gip$issue_importance_gov_traffic <-gip$CE02029
	gip$issue_importance_gov_defense <-gip$CE02030
	gip$issue_importance_gov_currency <-gip$CE02031
	gip$issue_importance_gov_economy <-gip$CE02032
	gip$issue_importance_gov_immigration <-gip$CE02033



	## issue importance individual
	
	gip$issue_importance_individual_random_item_order <-gip$hf009
	gip$issue_importance_individual_labormarket <-gip$CE02034
	gip$issue_importance_individual_foreignpolicy <-gip$CE02035
	gip$issue_importance_individual_education <-gip$CE02036
	gip$issue_importance_individual_participation <-gip$CE02037
	gip$issue_importance_individual_energy <-gip$CE02038
	
	gip$issue_importance_individual_eu <-gip$CE02039
	gip$issue_importance_individual_family <-gip$CE02040
	gip$issue_importance_individual_healthcare <-gip$CE02041
	gip$issue_importance_individual_equality <-gip$CE02042
	gip$issue_importance_individual_security <-gip$CE02043

	gip$issue_importance_individual_civilliberties <-gip$CE02044
	gip$issue_importance_individual_pension <-gip$CE02045
	gip$issue_importance_individual_debt <-gip$CE02046
	gip$issue_importance_individual_taxes <-gip$CE02047
	gip$issue_importance_individual_environment <-gip$CE02048

	gip$issue_importance_individual_traffic <-gip$CE02049
	gip$issue_importance_individual_defense <-gip$CE02050
	gip$issue_importance_individual_currency <-gip$CE02051
	gip$issue_importance_individual_economy <-gip$CE02052
	gip$issue_importance_individual_immigration <-gip$CE02053

	gip$unity_gov <-gip$CE02056
	gip$unity_party_cducsu <-gip$CE02057
	gip$unity_party_spd <-gip$CE02058
	gip$unity_party_fdp <-gip$CE02059
	gip$unity_party_gruene <-gip$CE02060
	gip$unity_party_linke <-gip$CE02061

	gip$economic_improvement_exp <-gip$CE02055 ## economy germany, CE02054 - economy individual


	## sophisticated/smart
	gip$math_question_ball <-gip$AB02020 ## correct answer 5 cent
	gip$math_question_machines <-gip$AB02021 	# correct answer 5 minutes
	gip$math_question_carpet <-gip$AB02022 # correct answer 47 days

	
	## government responsibility	
	gip$gridlock_resp <-gip$CE02067
	
		
##-----------------------------------------------------------	
	## Wave 3
##-----------------------------------------------------------	

	gip$pol_know_election_treshold <-gip$CD03001 # correct answer is 5 %
	gip$pol_know_chancelor <-gip$CD03002 # correct answer is Bundestag
	gip$pol_know_person_leyen_cdu <-gip$CD03003 # correct answer is Ursula von der Leyen CDU
	gip$pol_know_person_steinbrueck_spd <-gip$CD03004 # correct answer is Peer Steinbrück SPD
	gip$pol_know_person_bahr_fdp <-gip$CD03005 # correct answer is Daniel Bahr
	gip$pol_know_person_gysi_linke <-gip$CD03006 # correct answer is Gregor Gysi Linke
	gip$pol_know_person_trittin_greens <-gip$CD03007 # correct answer is Jürgen Trittin, Greens

	gip$thermometr_cdu <-gip$CD03008
	gip$thermometr_spd <-gip$CD03009
	gip$thermometr_fdp <-gip$CD03010
	gip$thermometr_greens <-gip$CD03011
	gip$thermometr_linke <-gip$CD03012




###### ----------------------------------------------------------------------------------------------------------------------------------
####
#### CREATE VARIABLES: Note that age, gender and education are already specified above above, variables follow the order from Table 2
####
#### -----------------------------------------------------------------------------------------------------------------------------------












###-------------------------------------------------------------------
## PARTISAN RATINGS
###-------------------------------------------------------------------

	var.sel<-which(names(gip)=="satisfaction_party_cducsu" | names(gip)=="satisfaction_party_fdp" | names(gip)=="satisfaction_gov")

	temp<-NA; temp<-gip
	names(gip)[var.sel]
	
for(i in 1: length(var.sel)){
	
	gip[,var.sel[i]]<-as.character(gip[,var.sel[i]])
	temp[,var.sel[i]]<-as.character(temp[,var.sel[i]])
	
	sel<-NA; sel<-which(temp[,var.sel[i]]=="1. -5 v\xf6llig unzufrieden"); gip[sel,var.sel[i]]<-1	
	sel<-NA; sel<-which(temp[,var.sel[i]]=="2. -4"); gip[sel,var.sel[i]]<-2	
	sel<-NA; sel<-which(temp[,var.sel[i]]=="3. -3"); gip[sel,var.sel[i]]<-3	
	sel<-NA; sel<-which(temp[,var.sel[i]]=="4. -2"); gip[sel,var.sel[i]]<-4	
	sel<-NA; sel<-which(temp[,var.sel[i]]=="5. -1"); gip[sel,var.sel[i]]<-5	
	sel<-NA; sel<-which(temp[,var.sel[i]]=="6. 0"); gip[sel,var.sel[i]]<-6	
	sel<-NA; sel<-which(temp[,var.sel[i]]=="7. +1"); gip[sel,var.sel[i]]<-7	
	sel<-NA; sel<-which(temp[,var.sel[i]]=="8. +2"); gip[sel,var.sel[i]]<-8	
	sel<-NA; sel<-which(temp[,var.sel[i]]=="9. +3"); gip[sel,var.sel[i]]<-9	
	sel<-NA; sel<-which(temp[,var.sel[i]]=="10. +4"); gip[sel,var.sel[i]]<-10	
	sel<-NA; sel<-which(temp[,var.sel[i]]=="11. +5"); gip[sel,var.sel[i]]<-11
	sel<-NA; sel<-which(temp[,var.sel[i]]=="11. +5 v\xf6llig zufrieden"); gip[sel,var.sel[i]]<-11		
	sel<-NA; sel<-which(temp[,var.sel[i]]=="12. +5 v\xf6llig zufrieden"); gip[sel,var.sel[i]]<-11	
	sel<-NA; sel<-which(temp[,var.sel[i]]=="-99. wei\xdf nicht/keine Meinung"); gip[sel,var.sel[i]]<-NA	
	sel<-NA; sel<-which(temp[,var.sel[i]]=="-90. item nonresponse"); gip[sel,var.sel[i]]<-NA		
		gip[,var.sel[i]]<-as.numeric(gip[,var.sel[i]])

		
}
	
	
	unique(gip[,c("satisfaction_party_cducsu","CE02002")])
	unique(gip[,c("satisfaction_party_fdp","CE02004")])
	unique(gip[,c("satisfaction_gov","CE02001")])
	
	# ## control
		# check<-cbind(gip[, var.sel[1]], temp[, var.sel[1]]); unique(check[,c(1,2)])
		# check<-cbind(gip[, var.sel[2]], temp[, var.sel[2]]); unique(check[,c(1,2)])
	
	##---------------------	
	##** for analyses use
	##--------------------
	gip$satisfaction_party_cducsu

	gip$satisfaction_party_fdp

	## Government Satisfaction
	gip$satisfaction_gov


###-----------------------------------------------------------------------------------------------
## POLICY PRIORITY MISMATCH MEASURES: PREPARATION
###-----------------------------------------------------------------------------------------------
	
	####-----------------------------------------------------------------------------------------------
	### ISSUE IMPORTANCE
	####-----------------------------------------------------------------------------------------------
		
	### INDIVIDUAL ISSUE IMPORTANCE (per voter)

	issue.importance.individual.variables<-grep("issue_importance_individual", names(gip))
	del.var<-which(names(gip)=="issue_importance_individual_random_item_order")
	issue.importance.individual.variables <-setdiff(issue.importance.individual.variables, del.var)
	names(gip)[issue.importance.individual.variables]
		
	## recode individual policy saliency
	temp<-NA; temp<-gip
	
	for (i in issue.importance.individual.variables) {		
		
		temp[,i]<-as.character(temp[,i])		
		gip[,i]<-as.character(gip[,i])		
		lab1<-which(temp[,i]=="1. sehr niedrige"); gip[lab1,i]<-1
		lab2<-which(temp[,i]=="2. niedrige"); gip[lab2,i]<-2
		lab3<-which(temp[,i]=="3. mittlere"); gip[lab3,i]<-3
		lab4<-which(temp[,i]=="4. hohe"); gip[lab4,i]<-4
		lab5<-which(temp[,i]=="5. sehr hohe"); gip[lab5,i]<-5
		lab6<-which(temp[,i]=="-99. wei\xdf nicht/keine Meinung"); gip[lab6,i]<-NA
		lab7<-which(temp[,i]=="-90. item nonresponse"); gip[lab7,i]<-NA
		gip[,i]<-as.numeric(gip[,i])		
					
	}	
		
	### GOVERNMENT ISSUE IMPORTANCE (per voter)

	issue.importance.gov.variables<-grep("issue_importance_gov", names(gip))
	names(gip)[issue.importance.gov.variables]
	del.var<-which(names(gip)=="issue_importance_gov_random_item_order" )
	issue.importance.gov.variables <-setdiff(issue.importance.gov.variables, del.var)
	names(gip)[issue.importance.gov.variables]

	temp<-NA; temp<-gip	
	for (i in issue.importance.gov.variables) {		
		
		temp[,i]<-as.character(temp[,i])		
		gip[,i]<-as.character(gip[,i])		
		lab1<-which(temp[,i]=="1. sehr niedrige"); gip[lab1,i]<-1
		lab2<-which(temp[,i]=="2. niedrige"); gip[lab2,i]<-2
		lab3<-which(temp[,i]=="3. mittlere"); gip[lab3,i]<-3
		lab4<-which(temp[,i]=="4. hohe"); gip[lab4,i]<-4
		lab5<-which(temp[,i]=="5. sehr hohe"); gip[lab5,i]<-5		
		lab6<-which(temp[,i]=="-99. wei\xdf nicht/keine Meinung"); gip[lab6,i]<-NA
		lab7<-which(temp[,i]=="-90. item nonresponse"); gip[lab7,i]<-NA
		gip[,i]<-as.numeric(gip[,i])		
					
	}		
				
###-----------------------------------------------------------------------------------------------
## POLICY PRIORITY MISMATCH: DIFFERENCE between GOVERNMENT issue importance and INDIVIDUAL issue importance 
###-----------------------------------------------------------------------------------------------
	## 0 indicates perfect match between voters and the government
	## + indicates that the government is perceived to overemphasiye policies (a particular policy is more important to the gov as compared to the voter)
	## - indicates that the government is perveived to underemphasiye policies (a particular policy is less important to the gov as compared to the voter)


	## make a function which calculates the difference between gov and individual issue importance only for these cases where an individual has indicated both, if only one or none are indicated set these cases to NA
	
	gov.voter.diff<-function(gov,voter) {
	n<-length(gov)
	temp<-rep(-99998, n) # create object with length gov salience and fill it with -99998 (large number needed for control)
	temp[is.na(gov)]<-NA; 	temp[is.na(voter)]<-NA # define cases for which ind, gov or both saliences are missing
	temp[!is.na(temp)]<-gov[!is.na(temp)]-voter[!is.na(temp)]# assign difference between voter and government salience for all cases except for those that are equal to -999, -90 or -99 (treated as NA)		
	temp.out<<-temp
	paste("assign temp.out to the variable of interest")
	}


## 1 labourmarket
	gov<-NA; gov<-gip$issue_importance_gov_labormarket
	voter<-NA; voter<-gip$issue_importance_individual_labormarket
	gov.voter.diff(gov=gov, voter=voter)
	gip$issue_importance_gov_voter_diff_labormarket<-temp.out	

## 2 foreignpolicy
	gov<-NA; gov<-gip$issue_importance_gov_foreignpolicy
	voter<-NA; voter<-gip$issue_importance_individual_foreignpolicy
	gov.voter.diff(gov=gov, voter=voter)
	gip$issue_importance_gov_voter_diff_foreignpolicy<-temp.out

## 3 education
	gov<-NA; gov<-gip$issue_importance_gov_education
	voter<-NA;voter<-gip$issue_importance_individual_education
	gov.voter.diff(gov=gov, voter=voter)
	gip$issue_importance_gov_voter_diff_education<-temp.out

## 4 participation
	gov<-NA; gov<-gip$issue_importance_gov_participation
	voter<-NA;voter<-gip$issue_importance_individual_participation
	gov.voter.diff(gov=gov, voter=voter)
	gip$issue_importance_gov_voter_diff_participation<-temp.out

## 5 energy
	gov<-NA; gov<-gip$issue_importance_gov_energy
	voter<-NA;voter<-gip$issue_importance_individual_energy
	gov.voter.diff(gov=gov, voter=voter)
	gip$issue_importance_gov_voter_diff_energy<-temp.out

## 6 eu
	gov<-NA; gov<-gip$issue_importance_gov_eu
	voter<-NA;voter<-gip$issue_importance_individual_eu
	gov.voter.diff(gov=gov, voter=voter)
	gip$issue_importance_gov_voter_diff_eu<-temp.out

## 7 family
	gov<-NA; gov<-gip$issue_importance_gov_family
	voter<-NA;voter<-gip$issue_importance_individual_family
	gov.voter.diff(gov=gov, voter=voter)
	gip$issue_importance_gov_voter_diff_family<-temp.out

## 8 healthcare
	gov<-NA; gov<-gip$issue_importance_gov_healthcare
	voter<-NA;voter<-gip$issue_importance_individual_healthcare
	gov.voter.diff(gov=gov, voter=voter)
	gip$issue_importance_gov_voter_diff_healthcare<-temp.out

## 9 equality
	gov<-NA; gov<-gip$issue_importance_gov_equality
	voter<-NA;voter<-gip$issue_importance_individual_equality
	gov.voter.diff(gov=gov, voter=voter)
	gip$issue_importance_gov_voter_diff_equality<-temp.out

## 10 security
	gov<-NA; gov<-gip$issue_importance_gov_security
	voter<-NA;voter<-gip$issue_importance_individual_security
	gov.voter.diff(gov=gov, voter=voter)
	gip$issue_importance_gov_voter_diff_security<-temp.out

## 11 civilliberties
	gov<-NA; gov<-gip$issue_importance_gov_civilliberties
	voter<-NA;voter<-gip$issue_importance_individual_civilliberties
	gov.voter.diff(gov=gov, voter=voter)
	gip$issue_importance_gov_voter_diff_civilliberties<-temp.out

## 12 pension
	gov<-NA; gov<-gip$issue_importance_gov_pension
	voter<-NA;voter<-gip$issue_importance_individual_pension
	gov.voter.diff(gov=gov, voter=voter)
	gip$issue_importance_gov_voter_diff_pension<-temp.out

## 13 debt
	gov<-NA; gov<-gip$issue_importance_gov_debt
	voter<-NA;voter<-gip$issue_importance_individual_debt
	gov.voter.diff(gov=gov, voter=voter)
	gip$issue_importance_gov_voter_diff_debt<-temp.out

## 14 taxes
	gov<-NA; gov<-gip$issue_importance_gov_taxes
	voter<-NA;voter<-gip$issue_importance_individual_taxes
	gov.voter.diff(gov=gov, voter=voter)
	gip$issue_importance_gov_voter_diff_taxes<-temp.out

## 15 environment
	gov<-NA; gov<-gip$issue_importance_gov_environment
	voter<-NA;voter<-gip$issue_importance_individual_environment
	gov.voter.diff(gov=gov, voter=voter)
	gip$issue_importance_gov_voter_diff_environment<-temp.out

## 16 traffic
	gov<-NA; gov<-gip$issue_importance_gov_traffic
	voter<-NA;voter<-gip$issue_importance_individual_traffic
	gov.voter.diff(gov=gov, voter=voter)
	gip$issue_importance_gov_voter_diff_traffic<-temp.out

## 17 defense
	gov<-NA; gov<-gip$issue_importance_gov_defense
	voter<-NA;voter<-gip$issue_importance_individual_defense
	gov.voter.diff(gov=gov, voter=voter)
	gip$issue_importance_gov_voter_diff_defense<-temp.out

## 18 currency
	gov<-NA; gov<-gip$issue_importance_gov_currency
	voter<-NA;voter<-gip$issue_importance_individual_currency
	gov.voter.diff(gov=gov, voter=voter)
	gip$issue_importance_gov_voter_diff_currency<-temp.out

## 19 economy
	gov<-NA; gov<-gip$issue_importance_gov_economy
	voter<-NA;voter<-gip$issue_importance_individual_economy
	gov.voter.diff(gov=gov, voter=voter)
	gip$issue_importance_gov_voter_diff_economy<-temp.out

## 20 immigration
	gov<-NA; gov<-gip$issue_importance_gov_immigration
	voter<-NA;voter<-gip$issue_importance_individual_immigration
	gov.voter.diff(gov=gov, voter=voter)
	gip$issue_importance_gov_voter_diff_immigration<-temp.out

###-----------------------------------------------------------------------------------------------
### AVERAGE Policy priority mismatch (Overall): avarage of the 20 policy salience differences per voter
###----------------------------------------------------------------------------------------------

	diff.variables<-grep("diff", names(gip))
	names(gip)[diff.variables]
		
	## AVERAGE of POSITIVE and NEGATIVE policy salience differences per voter
		gip$mean_policy_diff_per_voter <-apply(gip[, diff.variables],1,mean,na.rm=TRUE)
		summary(gip$mean_policy_diff_per_voter)
		gip$policy_discr_all_mean<-gip$mean_policy_diff_per_voter
	
		
	### AVARAGE of ABSOLUTE policy salience differences per voter	
		gip$mean_abs_policy_diff_per_voter <-apply(abs(gip[, diff.variables]),1,mean,na.rm=TRUE)
		summary(gip$mean_abs_policy_diff_per_voter)
	
	##---------------------	
	##** for analyses use
	##--------------------		
		gip$policy_discr_all<-gip$mean_abs_policy_diff_per_voter

###-----------------------------------------------------------------------------------------------
## DEFINE cdu/csu and fdp specific policies (see separate coding for the responsble party by policy in the 17 LP (November 2012), see Table 1, p. 137
###-----------------------------------------------------------------------------------------------	
	## fdp policies 
		## 1 Civil Liberties (civilliberties); ## 2 Economy (economy); ## 3 Energy (energy); ## 4 European Integration (eu); ## 5 Foreign Affairs (foreignpolicy); ## 6 Health Care System (healthcare)
		fdp.policies.list <-c("issue_importance_gov_voter_diff_foreignpolicy","issue_importance_gov_voter_diff_energy","issue_importance_gov_voter_diff_eu", "issue_importance_gov_voter_diff_healthcare", "issue_importance_gov_voter_diff_civilliberties", "issue_importance_gov_voter_diff_economy")

	## cdu/csu policies 
		## 7 Civic Participation (participation); ## 8 Common Currency (currency); ## 9 Defense (defense); ## 10 Education and Research (education); ## 11 Environmental Protection (environment); ## 12 Equality (equality); ## 13 Familiy (family); ## 14 Immigration and Integration (immigration); ## 15 Internal Security (security); ## 16 Labor Market (labormarket); ## 17 Pension Market (pension); ## 18 Public Debt (debt); ## 19 Tax System (taxes); ## 20 Transport (traffic) 		
	cdu.policies.list <-c("issue_importance_gov_voter_diff_labormarket","issue_importance_gov_voter_diff_education","issue_importance_gov_voter_diff_participation", "issue_importance_gov_voter_diff_family","issue_importance_gov_voter_diff_equality","issue_importance_gov_voter_diff_security", "issue_importance_gov_voter_diff_pension","issue_importance_gov_voter_diff_debt", "issue_importance_gov_voter_diff_taxes", "issue_importance_gov_voter_diff_environment","issue_importance_gov_voter_diff_traffic", "issue_importance_gov_voter_diff_defense","issue_importance_gov_voter_diff_currency","issue_importance_gov_voter_diff_immigration")
	
###-------------------------------------------------------------------
## AVERAGE Policy priority mismatch (PPM) (CDU/CSU policies): avarage of the 14 policy salience differences (CDU/CSU policies) per voter
###-------------------------------------------------------------------
	
	## define which PPM columns from gip are cdu/csu policy areas
		cdu.policies.gip<-which(is.element(names(gip), cdu.policies.list))
		names(gip)[cdu.policies.gip]
				
	## AVERAGE of POSITIVE and NEGATIVE policy salience differences per voter
		gip$mean_policy_diff_per_voter_cducsu_policies <-apply(gip[, cdu.policies.gip],1,mean,na.rm=TRUE)
		gip$policy_discr_cducsu_mean<-gip$mean_policy_diff_per_voter_cducsu_policies
	

	### AVARAGE of ABSOLUTE policy salience differences per voter	
		gip$mean_abs_policy_diff_per_voter_cducsu_policies <-apply(abs(gip[, cdu.policies.gip]),1,mean,na.rm=TRUE)	
		summary(gip$mean_abs_policy_diff_per_voter_cducsu_policies)

	##---------------------	
	##** for analyses use
	##--------------------		
		gip$policy_discr_cducsu<-gip$mean_abs_policy_diff_per_voter_cducsu_policies

###-------------------------------------------------------------------
## AVERAGE Policy priority mismatch (FDP policies): avarage of the 6 policy salience differences (FDP policies) per voter
###-------------------------------------------------------------------

	## define which PPM columns from gip are cdu/csu policy areas
		fdp.policies.gip<-which(is.element(names(gip), fdp.policies.list))
		names(gip)[fdp.policies.gip]
	
	### AVARAGE of ABSOLUTE policy salience differences per voter	
		gip$mean_policy_diff_per_voter_fdp_policies <-apply(gip[, fdp.policies.gip],1,mean,na.rm=TRUE)
		gip$policy_discr_fdp_mean<-gip$mean_policy_diff_per_voter_fdp_policies
	
	### AVARAGE of ABSOLUTE policy salience differences per voter	
		gip$mean_abs_policy_diff_per_voter_fdp_policies <-apply(abs(gip[, fdp.policies.gip]),1,mean,na.rm=TRUE)
		summary(gip$mean_abs_policy_diff_per_voter_fdp_policies)
	
	##---------------------	
	##** for analyses use
	##---------------------
	
		gip$policy_discr_fdp<-gip$mean_abs_policy_diff_per_voter_fdp_policies

###-------------------------------------------------------------------
## COHESION
###-------------------------------------------------------------------

	## Government cohesion
		temp<-NA; temp<-gip
		gip$unity_gov[temp$unity_gov<0]<-NA
		summary(gip$unity_gov); sd(gip$unity_gov, na.rm=T)
		unique(gip[,c("unity_gov","CE02056")])
		
		
	## CDU/CSU cohesion
		gip$unity_party_cducsu[temp$unity_party_cducsu<0]<-NA
		summary(gip$unity_party_cducsu); sd(gip$unity_party_cducsu, na.rm=T)
		unique(gip[,c("unity_party_cducsu","CE02057")])
		
	## FDP cohesion
		gip$unity_party_fdp[temp$unity_party_fdp <0]<-NA
		summary(gip$unity_party_fdp); sd(gip$unity_party_fdp, na.rm=T)
		unique(gip[,c("unity_party_fdp","CE02059")])
		
	## SPD cohesion
		gip$unity_party_spd[temp$unity_party_spd <0]<-NA
		summary(gip$unity_party_spd); sd(gip$unity_party_spd, na.rm=T)
		unique(gip[,c("unity_party_spd","CE02058")])
		
	## Gruene cohesion	
		gip$unity_party_gruene[temp$unity_party_gruene <0]<-NA
		summary(gip$unity_party_gruene); sd(gip$unity_party_gruene, na.rm=T)
		unique(gip[,c("unity_party_gruene","CE02060")])
 
	## Linke cohesion
		gip$unity_party_linke[temp$unity_party_linke <0]<-NA
		summary(gip$unity_party_linke); sd(gip$unity_party_linke, na.rm=T)
		unique(gip[,c("unity_party_linke","CE02061")])


		
	##---------------------	
	##** for analyses use
	##---------------------	
		gip$unity_gov; gip$unity_party_cducsu; gip$unity_party_fdp
		
		
		
###-------------------------------------------------------------------
## GOVERNMENT CONFLICT
###-------------------------------------------------------------------

	## Government conflict
	
		gip$gov_conflict<-((-1)*gip$unity_gov)+12
		unique(gip[,c("gov_conflict","unity_gov")])
		summary(gip$gov_conflict); sd(gip$gov_conflict, na.rm=T)
		
	##---------------------	
	##** for analyses use
	##---------------------	
		gip$gov_conflict	
		

	## partisan conflict
	
	gip$cducsu_conflict<-((-1)*gip$unity_party_cducsu)+12
			unique(gip[,c("unity_party_cducsu","cducsu_conflict")])

	gip$fdp_conflict<-((-1)*gip$unity_party_fdp)+12
				unique(gip[,c("unity_party_fdp","fdp_conflict")])

	gip$spd_conflict<-((-1)*gip$unity_party_spd)+12
				unique(gip[,c("unity_party_spd","spd_conflict")])
				
	gip$gruene_conflict<-((-1)*gip$unity_party_gruene)+12
				unique(gip[,c("unity_party_gruene","gruene_conflict")])
				
	gip$linke_conflict<-((-1)*gip$unity_party_linke)+12
				unique(gip[,c("unity_party_linke","linke_conflict")])
				
	
##------------------------------------------------
## NUMBER of POLICY AREAS with Do Not Know responses (do not know response for the individual OR government policy salience for a given policy area )
##------------------------------------------------


	diff<-grep("diff", names(gip))
	names(gip)[diff]
	diff<-diff[1:20]
	gip$diff_no_info<-1000 # random high number to check whether all cases have been assigned a number of missing policy areas
	
	for(i in 1:dim(gip)[1]){
		temp<-is.na(gip[i, diff])
		count.na<-table(cbind(temp[,1:20]))
		
		gip$diff_no_info[i]<-as.numeric(count.na["TRUE"]) # note if there is information for all 20 policy areas, NA is assigned
	}
	
	gip$diff_no_info[is.na(gip$diff_no_info)]<-0
	gip$diff_no_info[gip$diff_no_info==20]<-NA
	summary(gip$diff_no_info)
	sd(gip$diff_no_info, na.rm=T)

	##---------------------	
	##** for analyses use
	##---------------------	
		gip$diff_no_info
		
##------------------------------------------------
## AGE
##------------------------------------------------	
		gip$age_cat
		gip$age # this variable is used in original analyses

##------------------------------------------------
## GENDER
##------------------------------------------------	

		gip$woman
	
##------------------------------------------------
## EDUCATION
##------------------------------------------------	
	
		gip$education
	
##------------------------------------------------
## FAMILY SATISFACTION
##------------------------------------------------
		temp<-NA; temp<-gip
		table(gip$family_satisfaction)
		gip$family_satisfaction[temp$family_satisfaction<0]<-NA
	##---------------------	
	##** for analyses use
	##---------------------	
		gip$family_satisfaction
	
##------------------------------------------------
## FINANCIAL SATISFACTION SATISFACTION
##------------------------------------------------
		table(gip$financial_satisfaction)
		gip$financial_satisfaction[temp$financial_satisfaction <0]<-NA
	##---------------------	
	##** for analyses use
	##---------------------	
		gip$financial_satisfaction
	
##------------------------------------------------
## LEISURE SATISFACTION SATISFACTION
##------------------------------------------------
		table(gip$leisure_satisfaction)
		gip$leisure_satisfaction[temp$leisure_satisfaction <0]<-NA
	##---------------------	
	##** for analyses use
	##---------------------	
		gip$leisure_satisfaction
##------------------------------------------------
## RELIGION
##------------------------------------------------
		unique(gip$social_activity_religion)
		gip$social_activity_religion<-as.character(gip$social_activity_religion)
		temp<-gip
		gip$social_activity_religion[temp$social_activity_religion=="1. Ich bin kein Mitglied."]<-1
		gip$social_activity_religion[temp$social_activity_religion =="2. Ich bin passives Mitglied."]<-2
		gip$social_activity_religion[temp$social_activity_religion =="3. Ich bin aktives Mitglied."]<-3
		gip$social_activity_religion[temp$social_activity_religion =="-90. item nonresponse"]<-NA
		table(gip$social_activity_religion, useNA="always")
	
	##---------------------	
	##** for analyses use
	##---------------------	
		gip$religion_activity<-as.factor(gip$social_activity_religion)






####-----------------------------------------------------------------------------------------------
## LAST ELECTION: CDU/CSU, FDP, Opposition
####-----------------------------------------------------------------------------------------------
		
		
		gip$vote_last_election_adj<-NA
		gip$vote_last_election_adj[gip$vote_last_election=="3. CDU / CSU"]<-"cducsu"
		gip$vote_last_election_adj[gip$vote_last_election =="4. SPD"]<-"spd"
		gip$vote_last_election_adj[gip$vote_last_election =="5. FDP"]<-"fdp"
		gip$vote_last_election_adj[gip$vote_last_election =="6. B\xfcndnis 90 / Die Gr\xfcnen"]<-"greens"
		gip$vote_last_election_adj[gip$vote_last_election =="7. Die Linke"]<-"linke"
		gip$vote_last_election_adj[gip$vote_last_election =="8. NPD"]<-"npd"
		gip$vote_last_election_adj[gip$vote_last_election =="9. Piratenpartei"]<-"pirates"
		gip$vote_last_election_adj[gip$vote_last_election =="10. Andere Partei, und zwar (bitte eintragen):"]<-"other"

				unique(gip[,c("vote_last_election_adj",'vote_last_election')])

		
		
		
		
		unique(gip$vote.last.election)
		gip$vote_last_election_cducsu_fdp_opp<-NA
		gip$vote_last_election_cducsu_fdp_opp[gip$vote_last_election=="3. CDU / CSU"]<-"cducsu"
		gip$vote_last_election_cducsu_fdp_opp[gip$vote_last_election =="4. SPD"]<-"opposition"
		gip$vote_last_election_cducsu_fdp_opp[gip$vote_last_election =="5. FDP"]<-"fdp"
		gip$vote_last_election_cducsu_fdp_opp[gip$vote_last_election =="6. B\xfcndnis 90 / Die Gr\xfcnen"]<-"opposition"
		gip$vote_last_election_cducsu_fdp_opp[gip$vote_last_election =="7. Die Linke"]<-"opposition"
		gip$vote_last_election_cducsu_fdp_opp[gip$vote_last_election =="8. NPD"]<-"opposition"
		gip$vote_last_election_cducsu_fdp_opp[gip$vote_last_election =="9. Piratenpartei"]<-"opposition"
		gip$vote_last_election_cducsu_fdp_opp[gip$vote_last_election =="10. Andere Partei, und zwar (bitte eintragen):"]<-"opposition"

	
		## control labeling
		unique(gip[,c("vote_last_election_cducsu_fdp_opp",'vote_last_election')])

		##---------------------	
		##** for analyses use
		##---------------------	
		gip$vote_le3<-as.factor(gip$vote_last_election_cducsu_fdp_opp)		

	
	
		## last election vote dummies
		table(gip$vote_last_election_adj, useNA="always")
		unique(gip$vote_last_election)
		
		## cducsu (1)
		
		gip$vote_le_cducsu<-NA
		gip$vote_le_cducsu[!is.na(gip$vote_last_election_adj)]<-0
		gip$vote_le_cducsu[gip$vote_last_election_adj=="cducsu"]<-1
		unique(gip[,c("vote_last_election_adj","vote_last_election","vote_le_cducsu")])
		

		## fdp (2)
		gip$vote_le_fdp<-NA
		gip$vote_le_fdp[!is.na(gip$vote_last_election_adj)]<-0
		gip$vote_le_fdp[gip$vote_last_election_adj=="fdp"]<-1
		unique(gip[,c("vote_last_election_adj","vote_le_fdp","vote_last_election")])
		
		## spd (3)
		gip$vote_le_spd<-NA
		gip$vote_le_spd[!is.na(gip$vote_last_election_adj)]<-0
		gip$vote_le_spd[gip$vote_last_election_adj=="spd"]<-1
		unique(gip[,c("vote_last_election_adj","vote_le_spd","vote_last_election")])
		
		## gruene (4)
		gip$vote_le_greens<-NA
		gip$vote_le_greens[!is.na(gip$vote_last_election_adj)]<-0
		gip$vote_le_greens[gip$vote_last_election_adj=="greens"]<-1
		unique(gip[,c("vote_last_election_adj","vote_le_greens","vote_last_election")])
		
		
		## linke (5)
		gip$vote_le_linke<-NA
		gip$vote_le_linke[!is.na(gip$vote_last_election_adj)]<-0
		gip$vote_le_linke[gip$vote_last_election_adj=="linke"]<-1
		unique(gip[,c("vote_last_election_adj","vote_le_linke","vote_last_election")])
		
		
	
	
		## last election government party
		unique(gip$vote_last_election)
		gip$vote_last_election_gov_opp<-NA
		gip$vote_last_election_gov_opp[gip$vote_last_election=="3. CDU / CSU"]<-"gov"
		gip$vote_last_election_gov_opp[gip$vote_last_election =="4. SPD"]<-"opposition"
		gip$vote_last_election_gov_opp[gip$vote_last_election =="5. FDP"]<-"gov"
		gip$vote_last_election_gov_opp[gip$vote_last_election =="6. B\xfcndnis 90 / Die Gr\xfcnen"]<-"opposition"
		gip$vote_last_election_gov_opp[gip$vote_last_election =="7. Die Linke"]<-"opposition"
		gip$vote_last_election_gov_opp[gip$vote_last_election =="8. NPD"]<-"opposition"
		gip$vote_last_election_gov_opp[gip$vote_last_election =="9. Piratenpartei"]<-"opposition"
		gip$vote_last_election_gov_opp[gip$vote_last_election =="10. Andere Partei, und zwar (bitte eintragen):"]<-"opposition"

		## fo analyses use
		gip$vote_le_gov<-NA
		gip$vote_le_gov[gip$vote_last_election_gov_opp=="gov"]<-1
		gip$vote_le_gov[gip$vote_last_election_gov_opp=="opposition"]<-0
	
		
			
	
	
	
###-------------------------------------------------------------------
## Government Composition Knowledge
###-------------------------------------------------------------------	
	## create dummy for those who know that cdu/csu are in government
		gip$gov_knowledge_cducsu<-0
		gip$gov_knowledge_cducsu[gip$polinfo_govparticipation_cducsu=="1. Partei ist in der Bundesregierung"]<-1
		gip$gov_knowledge_cducsu[gip$polinfo_govparticipation_cducsu =="2. Partei ist in der Opposition"]<-0
		gip$gov_knowledge_cducsu[gip$polinfo_govparticipation_cducsu =="-99. wei\xdf nicht/keine Meinung"]<-0
		gip$gov_knowledge_cducsu[gip$polinfo_govparticipation_cducsu =="90. item nonresponse"]<-0
		gip$gov_knowledge_cducsu[is.na(gip$polinfo_govparticipation_cducsu)]<-NA		
		table(gip$gov_knowledge_cducsu,useNA="always")

	## create dummy for those who know that fdp is in government
		gip$gov_knowledge_fdp<-0
		gip$gov_knowledge_fdp[gip$polinfo_govparticipation_fdp =="1. Partei ist in der Bundesregierung"]<-1
		gip$gov_knowledge_fdp[gip$polinfo_govparticipation_fdp =="2. Partei ist in der Opposition"]<-0
		gip$gov_knowledge_fdp[gip$polinfo_govparticipation_fdp =="-99. wei\xdf nicht/keine Meinung"]<-0
		gip$gov_knowledge_fdp[gip$polinfo_govparticipation_fdp =="90. item nonresponse"]<-0
		gip$gov_knowledge_fdp[is.na(gip$polinfo_govparticipation_fdp)]<-NA
		table(gip$gov_knowledge_fdp,useNA="always")

	## create dummy for those who know that CDU/CSU and FDP are in the government

		gip$gov_knowledge_cducsu_fdp<-NA
		gip$gov_knowledge_cducsu_fdp[gip$gov_knowledge_fdp==1 & gip$gov_knowledge_cducsu==1]<-1
		gip$gov_knowledge_cducsu_fdp[gip$gov_knowledge_fdp==0 & gip$gov_knowledge_cducsu==0]<-0
		gip$gov_knowledge_cducsu_fdp[gip$gov_knowledge_fdp==1 & gip$gov_knowledge_cducsu==0]<-0
		gip$gov_knowledge_cducsu_fdp[gip$gov_knowledge_fdp==0 & gip$gov_knowledge_cducsu==1]<-0
		table(gip$gov_knowledge_cducsu_fdp, useNA="always")
		summary(gip$gov_knowledge_cducsu_fdp)
	##---------------------	
	##** for analyses select gip$gov_knowledge_fdp==1 and gip$gov_knowledge_cducsu==1
	##---------------------	
	
	
###-------------------------------------------------------------------	
## 	Economic Decline
###-------------------------------------------------------------------
	unique(gip$economic_improvement_exp)
	gip$econ_improve<-NA
	gip$econ_improve[gip$economic_improvement_exp=="1. deutliche Verschlechterung"]<-1
	gip$econ_improve[gip$economic_improvement_exp =="2. leichte Verschlechterung"]<-2
	gip$econ_improve[gip$economic_improvement_exp =="3. weder Verschlechterung noch Verbesserung"]<-3
	gip$econ_improve[gip$economic_improvement_exp =="4. leichte Verbesserung"]<-4
	gip$econ_improve[gip$economic_improvement_exp =="5. deutliche Verbesserung"]<-5

	unique(gip$economic_improvement_exp)
	gip$econ_decline<-NA
	gip$econ_decline[gip$economic_improvement_exp=="1. deutliche Verschlechterung"]<-5
	gip$econ_decline[gip$economic_improvement_exp =="2. leichte Verschlechterung"]<-4
	gip$econ_decline[gip$economic_improvement_exp =="3. weder Verschlechterung noch Verbesserung"]<-3
	gip$econ_decline[gip$economic_improvement_exp =="4. leichte Verbesserung"]<-2
	gip$econ_decline[gip$economic_improvement_exp =="5. deutliche Verbesserung"]<-1
	unique(gip[,c("econ_decline","economic_improvement_exp")])

	
	## dummy
	
	gip$econ_decline_dummy<-NA
	gip$econ_decline_dummy[gip$economic_improvement_exp=="1. deutliche Verschlechterung"]<-1
	gip$econ_decline_dummy[gip$economic_improvement_exp =="2. leichte Verschlechterung"]<-1
	gip$econ_decline_dummy[gip$economic_improvement_exp =="3. weder Verschlechterung noch Verbesserung"]<-0
	gip$econ_decline_dummy[gip$economic_improvement_exp =="4. leichte Verbesserung"]<-0
	gip$econ_decline_dummy[gip$economic_improvement_exp =="5. deutliche Verbesserung"]<-0
	unique(gip[,c("econ_decline_dummy","economic_improvement_exp")])
	
	
	##---------------------	
	##** for analyses use
	##---------------------	

	table(gip$econ_decline)
	table(gip$econ_decline_dummy)
	

		
###-------------------------------------------------------------------	
## 	L-R selfplacement
###-------------------------------------------------------------------
		
		unique(gip$lr_selfplacement_a)
		unique(gip$lr_selfplacement_b)
		unique(gip[,c("lr_selfplacement_a","lr_selfplacement_b")])

		
		gip$lr_self<-NA
		a.not.nas<-which(!is.na(gip$lr_selfplacement_a))
		b.not.nas<-which(!is.na(gip$lr_selfplacement_b))
		gip$lr_selfplacement_a[a.not.nas]
		gip$lr_selfplacement_b[b.not.nas]
		
		gip$lr_self[a.not.nas]<-gip$lr_selfplacement_a[a.not.nas]
		gip$lr_self[b.not.nas]<-gip$lr_selfplacement_b[b.not.nas]
		unique(gip[,c("lr_self","lr_selfplacement_a","lr_selfplacement_b")])
		temp<-NA; temp<-gip$lr_self
		gip$lr_self[temp <0]<-NA
		
###-------------------------------------------------------------------	
## 	L-R party placement
###-------------------------------------------------------------------
		
		unique(gip$lr_placement_cdu_a)
		unique(gip$lr_placement_cdu_b)
		unique(gip[,c("lr_placement_cdu_a","lr_placement_cdu_b")])

	## CDU
		gip$lr_cdu<-NA
		a.not.nas<-NA; a.not.nas<-which(!is.na(gip$lr_placement_cdu_a))
		b.not.nas<-NA; b.not.nas<-which(!is.na(gip$lr_placement_cdu_b))
		gip$lr_placement_cdu_a[a.not.nas]
		gip$lr_placement_cdu_b[b.not.nas]
		
		gip$lr_cdu[a.not.nas]<-gip$lr_placement_cdu_a[a.not.nas]
		gip$lr_cdu[b.not.nas]<-gip$lr_placement_cdu_b[b.not.nas]
		unique(gip[,c("lr_cdu","lr_placement_cdu_a","lr_placement_cdu_b")])
		temp<-NA; temp<-gip$lr_cdu
		gip$lr_cdu[temp <0]<-NA


	## CSU
		gip$lr_csu<-NA
		a.not.nas<-NA;a.not.nas<-which(!is.na(gip$lr_placement_csu_a)); gip$lr_placement_csu_a[a.not.nas]
		b.not.nas<-NA; b.not.nas<-which(!is.na(gip$lr_placement_csu_b)); gip$lr_placement_csu_b[b.not.nas]
				
		gip$lr_csu[a.not.nas]<-gip$lr_placement_csu_a[a.not.nas]
		gip$lr_csu[b.not.nas]<-gip$lr_placement_csu_b[b.not.nas]
		unique(gip[,c("lr_csu","lr_placement_csu_a","lr_placement_csu_b")])
		temp<-NA; temp<-gip$lr_csu
		gip$lr_csu[temp <0]<-NA
		
	## SPD
		gip$lr_spd<-NA
		a.not.nas<-NA; a.not.nas<-which(!is.na(gip$lr_placement_spd_a)); gip$lr_placement_spd_a[a.not.nas]
		b.not.nas<-NA; b.not.nas<-which(!is.na(gip$lr_placement_spd_b)); gip$lr_placement_spd_b[b.not.nas]
				
		gip$lr_spd[a.not.nas]<-gip$lr_placement_spd_a[a.not.nas]
		gip$lr_spd[b.not.nas]<-gip$lr_placement_spd_b[b.not.nas]
		unique(gip[,c("lr_spd","lr_placement_spd_a","lr_placement_spd_b")])
		temp<-NA; temp<-gip$lr_spd
		gip$lr_spd[temp <0]<-NA
		
	## FDP
		gip$lr_fdp<-NA
		a.not.nas<-NA; a.not.nas<-which(!is.na(gip$lr_placement_fdp_a)); gip$lr_placement_fdp_a[a.not.nas]
		b.not.nas<-NA; b.not.nas<-which(!is.na(gip$lr_placement_fdp_b)); gip$lr_placement_fdp_b[b.not.nas]
				
		gip$lr_fdp[a.not.nas]<-gip$lr_placement_fdp_a[a.not.nas]
		gip$lr_fdp[b.not.nas]<-gip$lr_placement_fdp_b[b.not.nas]
		unique(gip[,c("lr_fdp","lr_placement_fdp_a","lr_placement_fdp_b")])
		temp<-NA; temp<-gip$lr_fdp
		gip$lr_fdp[temp <0]<-NA	
	
	## Greens
		gip$lr_greens<-NA
		a.not.nas<-NA; a.not.nas<-which(!is.na(gip$lr_placement_greens_a)); gip$lr_placement_greens_a[a.not.nas]
		b.not.nas<-NA; b.not.nas<-which(!is.na(gip$lr_placement_greens_b)); gip$lr_placement_greens_b[b.not.nas]
				
		gip$lr_greens[a.not.nas]<-gip$lr_placement_greens_a[a.not.nas]
		gip$lr_greens[b.not.nas]<-gip$lr_placement_greens_b[b.not.nas]
		unique(gip[,c("lr_greens","lr_placement_greens_a","lr_placement_greens_b")])
		temp<-NA; temp<-gip$lr_greens
		gip$lr_greens[temp <0]<-NA	
		
		
	## Linke	
		gip$lr_linke<-NA
		a.not.nas<-NA; a.not.nas<-which(!is.na(gip$lr_placement_linke_a)); gip$lr_placement_linke_a[a.not.nas]
		b.not.nas<-NA; b.not.nas<-which(!is.na(gip$lr_placement_linke_b)); gip$lr_placement_linke_b[b.not.nas]
				
		gip$lr_linke[a.not.nas]<-gip$lr_placement_linke_a[a.not.nas]
		gip$lr_linke[b.not.nas]<-gip$lr_placement_linke_b[b.not.nas]
		unique(gip[,c("lr_linke","lr_placement_linke_a","lr_placement_linke_b")])
		temp<-NA; temp<-gip$lr_linke
		gip$lr_linke[temp <0]<-NA		
				
	## NPD
		gip$lr_npd<-NA
		a.not.nas<-NA; a.not.nas<-which(!is.na(gip$lr_placement_npd_a)); gip$lr_placement_npd_a[a.not.nas]
		b.not.nas<-NA; b.not.nas<-which(!is.na(gip$lr_placement_npd_b)); gip$lr_placement_npd_b[b.not.nas]
				
		gip$lr_npd[a.not.nas]<-gip$lr_placement_npd_a[a.not.nas]
		gip$lr_npd[b.not.nas]<-gip$lr_placement_npd_b[b.not.nas]
		unique(gip[,c("lr_npd","lr_placement_npd_a","lr_placement_npd_b")])
		temp<-NA; temp<-gip$lr_npd
		gip$lr_npd[temp <0]<-NA		
		
	## Pirates
		gip$lr_pirates<-NA
		a.not.nas<-NA; a.not.nas<-which(!is.na(gip$lr_placement_pirates_a)); gip$lr_placement_pirates_a[a.not.nas]
		b.not.nas<-NA; b.not.nas<-which(!is.na(gip$lr_placement_pirates_b)); gip$lr_placement_pirates_b[b.not.nas]
				
		gip$lr_pirates[a.not.nas]<-gip$lr_placement_pirates_a[a.not.nas]
		gip$lr_pirates[b.not.nas]<-gip$lr_placement_pirates_b[b.not.nas]
		unique(gip[,c("lr_pirates","lr_placement_pirates_a","lr_placement_pirates_b")])
		temp<-NA; temp<-gip$lr_pirates
		gip$lr_pirates[temp <0]<-NA	
		
		
	## gov position
	gip$lr_gov<-(gip$lr_cdu+gip$lr_csu+gip$lr_fdp)/3	
	gip$lr_gov_sw<-((31.2*gip$lr_cdu)+(7.2*gip$lr_csu)+(15*gip$lr_fdp))/(31.2+7.2+15)	
	#plot(gip$lr_gov_sw, gip$lr_gov)	
	rcorr(gip$lr_gov_sw, gip$lr_gov)
	cor(gip$lr_gov_sw, gip$lr_gov, use="complete.obs", method="pearson")
		
###-------------------------------------------------------------------	
## 	L-R Gov Distance
###-------------------------------------------------------------------
		
		
		## seat weighted
		gip$lr_cducsu_sw<-((31.2*gip$lr_cdu)+(7.2*gip$lr_csu))/(31.2+7.2)
		gip$lr_gov_distance_sw<-abs((gip$lr_cducsu_sw-gip$lr_fdp))
		gip$lr_gov_parties_distance_sw<-(abs((31.2+7.2)*(gip$lr_cdu-gip$lr_csu))+ abs((31.2+15)*(gip$lr_cdu-gip$lr_fdp))+ abs((7.2+15)*(gip$lr_csu-gip$lr_fdp)))/((31.2+7.2)+(31.2+15)+(7.2+15))
		#plot(gip$lr_gov_distance_sw, gip$lr_gov_parties_distance_sw)	
		
				
		## average
		gip$lr_cducsu<-(gip$lr_cdu+gip$lr_csu)/2
		gip$lr_gov_distance<-abs((gip$lr_cducsu-gip$lr_fdp))
		gip$lr_gov_parties_distance<-(abs(gip$lr_cdu-gip$lr_csu)+ abs(gip$lr_cdu-gip$lr_fdp)+ abs(gip$lr_csu-gip$lr_fdp))/3
		#plot(gip$lr_gov_distance, gip$lr_gov_parties_distance)	
		
		
		
		gip[1:5,c("lr_gov_distance_sw","lr_gov_distance")]
		gip[1:5,c("lr_gov_parties_distance_sw","lr_gov_parties_distance")]	
		gip[1:5,c("lr_cducsu_sw","lr_cducsu")]
		
	##---------------------	
	##** for analyses use
	##---------------------	
		gip$lr_gov_distance
		gip$lr_gov_parties_distance
	
	## Robustness
		gip$lr_gov_distance.sw
		gip$lr_gov_parties_distance.sw
		
	## LR distance to each party and the government
	
	gip$lr_self_cducsu<-abs(gip$lr_self-gip$lr_cducsu)
	gip$lr_self_cducsu_sw<-abs(gip$lr_self-gip$lr_cducsu_sw)	
	gip$lr_self_cdu<-abs(gip$lr_self-gip$lr_cdu)
	gip$lr_self_csu<-abs(gip$lr_self-gip$lr_csu)
	gip$lr_self_spd<-abs(gip$lr_self-gip$lr_spd)
	gip$lr_self_greens<-abs(gip$lr_self-gip$lr_greens)
	gip$lr_self_fdp<-abs(gip$lr_self-gip$lr_fdp)
	gip$lr_self_linke<-abs(gip$lr_self-gip$lr_linke)
	gip$lr_self_npd<-abs(gip$lr_self-gip$lr_npd)
	gip$lr_self_pirates<-abs(gip$lr_self-gip$lr_pirates)
	gip$lr_self_gov<-abs(gip$lr_self-gip$lr_gov)
	gip$lr_self_gov_sw<-abs(gip$lr_self-gip$lr_gov_sw)
	


	
		
	
	
		
	
	
		
		
		
		
###-------------------------------------------------------------------	
## 	intended vote
###-------------------------------------------------------------------
	gip$voting_intention_gip2
		
	unique(gip$voting_intention_gip2)
		gip$vote_intention<-NA
		gip$vote_intention[gip$voting_intention_gip2 =="3. CDU/CSU"]<-"cducsu"
		gip$vote_intention[gip$voting_intention_gip2 =="4. SPD"]<-"spd"
		gip$vote_intention[gip$voting_intention_gip2 =="5. FDP"]<-"fdp"
		gip$vote_intention[gip$voting_intention_gip2 =="6. B\xfcndnis 90/Die Gr\xfcnen"]<-"greens"
		gip$vote_intention[gip$voting_intention_gip2 =="7. Die Linke"]<-"linke"
		gip$vote_intention[gip$voting_intention_gip2 =="8. NPD"]<-"npd"
		gip$vote_intention[gip$voting_intention_gip2 =="9. Piratenpartei"]<-"pirates"
		gip$vote_intention[gip$voting_intention_gip2 =="10. Ich w\xfcrde die folgende Partei w\xe4hlen:"]<-"other"

		## control labeling
		unique(gip[,c("vote_intention",'voting_intention_gip2')])

	##---------------------	
	##** for analyses use
	##---------------------	
		gip$vote_ne<-as.factor(gip$vote_intention)		
		



###-------------------------------------------------------------------	
## 	intended vote: cdu/csu vs other (wave 2)
###-------------------------------------------------------------------

		gip$vote_intention_cducsu<-NA
		gip$vote_intention_cducsu[gip$vote_intention =="cducsu"]<-1
		gip$vote_intention_cducsu[gip$vote_intention =="spd"]<-0
		gip$vote_intention_cducsu[gip$vote_intention =="fdp"]<-0
		gip$vote_intention_cducsu[gip$vote_intention =="greens"]<-0
		gip$vote_intention_cducsu[gip$vote_intention =="linke"]<-0
		gip$vote_intention_cducsu[gip$vote_intention =="npd"]<-0
		gip$vote_intention_cducsu[gip$vote_intention =="pirates"]<-0
		gip$vote_intention_cducsu[gip$vote_intention =="other"]<-0


###-------------------------------------------------------------------	
## 	intended vote: fdp vs other (wave 2)
###-------------------------------------------------------------------

		gip$vote_intention_fdp<-NA
		gip$vote_intention_fdp[gip$vote_intention =="cducsu"]<-0
		gip$vote_intention_fdp[gip$vote_intention =="spd"]<-0
		gip$vote_intention_fdp[gip$vote_intention =="fdp"]<-1
		gip$vote_intention_fdp[gip$vote_intention =="greens"]<-0
		gip$vote_intention_fdp[gip$vote_intention =="linke"]<-0
		gip$vote_intention_fdp[gip$vote_intention =="npd"]<-0
		gip$vote_intention_fdp[gip$vote_intention =="pirates"]<-0
		gip$vote_intention_fdp[gip$vote_intention =="other"]<-0






###-------------------------------------------------------------------	
## 	intended vote: cdu/csu, fdp, opposition
###-------------------------------------------------------------------

		gip$vote_intention_cducsu_fdp_opp<-NA
		gip$vote_intention_cducsu_fdp_opp[gip$vote_intention =="cducsu"]<-"cducsu"
		gip$vote_intention_cducsu_fdp_opp[gip$vote_intention =="spd"]<-"opposition"
		gip$vote_intention_cducsu_fdp_opp[gip$vote_intention =="fdp"]<-"fdp"
		gip$vote_intention_cducsu_fdp_opp[gip$vote_intention =="greens"]<-"opposition"
		gip$vote_intention_cducsu_fdp_opp[gip$vote_intention =="linke"]<-"opposition"
		gip$vote_intention_cducsu_fdp_opp[gip$vote_intention =="npd"]<-"opposition"
		gip$vote_intention_cducsu_fdp_opp[gip$vote_intention =="pirates"]<-"opposition"
		gip$vote_intention_cducsu_fdp_opp[gip$vote_intention =="other"]<-"opposition"



	## control labeling
		unique(gip[,c("vote_intention_cducsu_fdp_opp",'voting_intention_gip2')])

	##---------------------	
	##** for analyses use (next election)
	##---------------------	
		gip$vote_ne3<-as.factor(gip$vote_intention_cducsu_fdp_opp)		



###-------------------------------------------------------------------	
## 	intended vote: gov, opposition
###-------------------------------------------------------------------


		gip$vote_intention_gov<-NA
		gip$vote_intention_gov[gip$vote_intention =="cducsu"]<-1
		gip$vote_intention_gov[gip$vote_intention =="spd"]<-0
		gip$vote_intention_gov[gip$vote_intention =="fdp"]<-1
		gip$vote_intention_gov[gip$vote_intention =="greens"]<-0
		gip$vote_intention_gov[gip$vote_intention =="linke"]<-0
		gip$vote_intention_gov[gip$vote_intention =="npd"]<-0
		gip$vote_intention_gov[gip$vote_intention =="pirates"]<-0
		gip$vote_intention_gov[gip$vote_intention =="other"]<-0


		unique(gip[,c("vote_intention_cducsu_fdp_opp",'voting_intention_gip2',"vote_intention_gov")])


###-------------------------------------------------------------------	
## 	Party identification
###-------------------------------------------------------------------

table(gip$party_identification_dummy, useNA="always")

		unique(gip[,c("party_identification_dummy",'party_identification',"vote_last_election")])
		unique(gip[,c("party_identification")])

	
	## party identification dymmy clean
		gip$party_identification_dummy_adj<-NA
		gip$party_identification_dummy_adj[gip$party_identification_dummy=="1. Ja"]<-1
		gip$party_identification_dummy_adj[gip$party_identification_dummy=="2. Nein"]<-0
	
			unique(gip[,c("party_identification_dummy","party_identification_dummy_adj")])

	
	
	## create variable which indicates whether	the survey participants identify with the party they voted for in the last federal elections
	
		gip$party_identification_adj<-NA
		gip$party_identification_adj[gip$party_identification=="1. CDU / CSU"]<-"cducsu"
		gip$party_identification_adj[gip$party_identification=="2. SPD"]<-"spd"
		gip$party_identification_adj[gip$party_identification=="3. FDP"]<-"fdp"
		gip$party_identification_adj[gip$party_identification=="4. B\xfcndnis 90 / Die Gr\xfcnen"]<-"greens"
		gip$party_identification_adj[gip$party_identification=="5. Die Linke"]<-"linke"
		gip$party_identification_adj[gip$party_identification=="6. NPD"]<-"npd"
		gip$party_identification_adj[gip$party_identification=="7. Andere Partei"]<-"other"
	
		unique(gip[,c("party_identification_dummy",'party_identification_adj',"vote_last_election_adj")])
			unique(gip[,c("party_identification_adj","party_identification_dummy_adj")])

		
	## Gov = Opposition identificaiton
		
		gip$party_identification_cducsu_fdp_opp<-NA
		gip$party_identification_cducsu_fdp_opp[gip$party_identification=="1. CDU / CSU"]<-"cducsu"
		gip$party_identification_cducsu_fdp_opp[gip$party_identification=="2. SPD"]<-"opposition"
		gip$party_identification_cducsu_fdp_opp[gip$party_identification=="3. FDP"]<-"fdp"
		gip$party_identification_cducsu_fdp_opp[gip$party_identification=="4. B\xfcndnis 90 / Die Gr\xfcnen"]<-"opposition"
		gip$party_identification_cducsu_fdp_opp[gip$party_identification=="5. Die Linke"]<-"opposition"
		gip$party_identification_cducsu_fdp_opp[gip$party_identification=="6. NPD"]<-"opposition"
		gip$party_identification_cducsu_fdp_opp[gip$party_identification=="7. Andere Partei"]<-"opposition"
	
		
		gip$party_identification_gov_opp<-NA
		gip$party_identification_gov_opp[gip$party_identification=="1. CDU / CSU"]<-"gov"
		gip$party_identification_gov_opp[gip$party_identification=="2. SPD"]<-"opposition"
		gip$party_identification_gov_opp[gip$party_identification=="3. FDP"]<-"gov"
		gip$party_identification_gov_opp[gip$party_identification=="4. B\xfcndnis 90 / Die Gr\xfcnen"]<-"opposition"
		gip$party_identification_gov_opp[gip$party_identification=="5. Die Linke"]<-"opposition"
		gip$party_identification_gov_opp[gip$party_identification=="6. NPD"]<-"opposition"
		gip$party_identification_gov_opp[gip$party_identification=="7. Andere Partei"]<-"opposition"
	
		
		unique(gip[,c("party_identification_cducsu_fdp_opp",'party_identification_gov_opp',"party_identification")])


		gip$party_identification_gov<-NA
		gip$party_identification_gov[gip$party_identification_dummy_adj==1]<-0
		gip$party_identification_gov[gip$party_identification_adj=="cducsu"| gip$party_identification_adj=="fdp"]<-1


		gip$party_identification_gov_nas_as_0<-0
		gip$party_identification_gov_nas_as_0[gip$party_identification_adj=="cducsu"| gip$party_identification_adj=="fdp"]<-1
		table(gip$party_identification_gov_nas_as_0, useNA="always")


		unique(gip[,c("party_identification_gov","party_identification_dummy_adj","party_identification_cducsu_fdp_opp",'party_identification_gov_opp',"party_identification")])


		gip$party_identification_cducsu<-0
		#gip$party_identification_cducsu<-NA
		#gip$party_identification_cducsu[gip$party_identification_dummy_adj==1]<-0
		gip$party_identification_cducsu[gip$party_identification_adj=="cducsu"]<-1
		
			unique(gip[,c("party_identification_adj","party_identification_cducsu")])
			table(gip$party_identification_cducsu)
	
		
		
		gip$party_identification_fdp<-0
		#gip$party_identification_fdp<-NA
		#gip$party_identification_fdp[gip$party_identification_dummy_adj==1]<-0
		gip$party_identification_fdp[gip$party_identification_adj=="fdp"]<-1
		
			unique(gip[,c("party_identification_adj","party_identification_fdp")])
			table(gip$party_identification_fdp)
		
	
	
		gip$party_identification_greens<-0
		#gip$party_identification_greens<-NA
		#gip$party_identification_greens[gip$party_identification_dummy_adj==1]<-0
		gip$party_identification_greens[gip$party_identification_adj=="greens"]<-1
		
			unique(gip[,c("party_identification_adj","party_identification_greens")])
			table(gip$party_identification_greens)
	
		gip$party_identification_spd<-0
		#gip$party_identification_spd <-NA
		#gip$party_identification_spd[gip$party_identification_dummy_adj==1]<-0
		gip$party_identification_spd[gip$party_identification_adj=="spd"]<-1
		
			unique(gip[,c("party_identification_adj","party_identification_spd")])
			table(gip$party_identification_spd)
	
		gip$party_identification_linke<-0
		#gip$party_identification_linke <-NA
		#gip$party_identification_linke[gip$party_identification_dummy_adj==1]<-0
		gip$party_identification_linke[gip$party_identification_adj=="linke"]<-1
		
			unique(gip[,c("party_identification_adj","party_identification_linke")])
			table(gip$party_identification_linke)
	
		gip$party_identification_npd<-0
		#gip$party_identification_npd <-NA
		#gip$party_identification_npd[gip$party_identification_dummy_adj==1]<-0
		gip$party_identification_npd[gip$party_identification_adj=="npd"]<-1
		
			unique(gip[,c("party_identification_adj","party_identification_npd")])
			table(gip$party_identification_npd)
	
	
	
		
	## identification with party from last vote	
		nas<-is.na(gip$party_identification_dummy_adj)		
		nas2<-which(is.na(gip$party_identification_adj) & gip$party_identification_dummy_adj==1)
		nas3<-which(is.na(gip$vote_last_election_adj) & gip$party_identification_dummy_adj==1)
		id<-gip$party_identification_adj==gip$vote_last_election_adj
		no.id<-which(gip$party_identification_dummy_adj==0)
		no.id2<-which(gip$party_identification_dummy_adj==1 & gip$party_identification_adj!=gip$vote_last_election_adj)
	
		
		gip$last_vote_identification<-9999
		gip$last_vote_identification[nas]<-NA
		gip$last_vote_identification[nas2]<-NA
		gip$last_vote_identification[nas3]<-NA
		gip$last_vote_identification[id]<-1
		gip$last_vote_identification[no.id]<-0
		gip$last_vote_identification[no.id2]<-0
		
		unique(gip[,c("party_identification_dummy_adj",'party_identification_adj',"vote_last_election_adj","last_vote_identification")])

		
	## identification with cdu/csu, fdp or opposition party from last vote	(CORRECT, there is no var cducsu_fdp_opp_identification)

		nas<-NA; nas<-is.na(gip$party_identification_dummy_adj)		
		nas2<-NA;nas2<-which(is.na(gip$party_identification_cducsu_fdp_opp) & gip$party_identification_dummy_adj==1)
		nas3<-NA;nas3<-which(is.na(gip$vote_last_election_cducsu_fdp_opp) & gip$party_identification_dummy_adj==1)
		id<-NA;id<-gip$party_identification_cducsu_fdp_opp ==gip$vote_last_election_cducsu_fdp_opp
		no.id<-NA; no.id<-which(gip$party_identification_dummy_adj==0)
		no.id2<-NA; no.id2<-which(gip$party_identification_dummy_adj==1 & gip$party_identification_cducsu_fdp_opp!=gip$vote_last_election_cducsu_fdp_opp)
	
		

		gip$last_vote_cducsu_fdp_opp_identification <-9999
		gip$last_vote_cducsu_fdp_opp_identification[nas]<-NA
		gip$last_vote_cducsu_fdp_opp_identification[nas2]<-NA
		gip$last_vote_cducsu_fdp_opp_identification[nas3]<-NA
		gip$last_vote_cducsu_fdp_opp_identification[id]<-1
		gip$last_vote_cducsu_fdp_opp_identification[no.id]<-0
		gip$last_vote_cducsu_fdp_opp_identification[no.id2]<-0

		class(gip$party_identification_cducsu_fdp_opp)
		class(gip$vote_last_election_cducsu_fdp_opp)
		check<-which(gip$party_identification_cducsu_fdp_opp!=gip$vote_last_election_cducsu_fdp_opp)
			
		unique(gip[check,c("party_identification_cducsu_fdp_opp","vote_last_election_cducsu_fdp_opp")])	
									unique(gip[,c("party_identification_dummy_adj",'party_identification_cducsu_fdp_opp',"vote_last_election_cducsu_fdp_opp","last_vote_cducsu_fdp_opp_identification")])

## alternative for party identification - party member or not


	table(gip$party_member, useNA="always")
	
	
	gip$party_member_cat<-NA
	gip$party_member_cat[gip$party_member=="1. Ich bin kein Mitglied."]<-0
	gip$party_member_cat[gip$party_member=="2. Ich bin passives Mitglied."]<-1
	gip$party_member_cat[gip$party_member=="3. Ich bin aktives Mitglied."]<-2
	
	gip$party_member_dummy<-NA
	gip$party_member_dummy[gip$party_member=="1. Ich bin kein Mitglied."]<-0
	gip$party_member_dummy[gip$party_member=="2. Ich bin passives Mitglied."]<-1
	gip$party_member_dummy[gip$party_member=="3. Ich bin aktives Mitglied."]<-1
			
		
	unique(gip[,c("party_member","party_member_cat","party_member_dummy")])	
	table(gip$party_member_dummy)
	
	
	
	## reform competence
	
	## CDU/CSU
	gip$CE02069 # cducsu
	unique(gip$CE02069)
	gip$competence_cducsu<-1
	gip$competence_cducsu[gip$CE02069=="-90. item nonresponse" | gip$CE02069=="-99. wei\xdf nicht/keine Meinung"]<-NA
	gip$competence_cducsu[is.na(gip$CE02069)]<-NA
	gip$competence_cducsu[gip$CE02069=="22. In keinem der hier aufgef\xfchrten Bereiche."]<-0	
	unique(gip[,c("competence_cducsu","CE02069")])	
	
	## count NAs as 0	
	gip$competence_cducsu_nas_as_0<-1
	gip$competence_cducsu_nas_as_0[gip$CE02069=="-90. item nonresponse" | gip$CE02069=="-99. wei\xdf nicht/keine Meinung"]<-0
	gip$competence_cducsu_nas_as_0[is.na(gip$CE02069)]<-0
	gip$competence_cducsu_nas_as_0[gip$CE02069=="22. In keinem der hier aufgef\xfchrten Bereiche."]<-0
	unique(gip[,c("competence_cducsu_nas_as_0","CE02069")])	

	table(gip$competence_cducsu, useNA='always')
	table(gip$competence_cducsu_nas_as_0, useNA='always')

	
	
	
	## SPD
	unique(gip$CE02070)
	gip$competence_spd <-1
	gip$competence_spd[gip$CE02070=="-90. item nonresponse" | gip$CE02070=="-99. wei\xdf nicht/keine Meinung"]<-NA
	gip$competence_spd[is.na(gip$CE02070)]<-NA
	gip$competence_spd[gip$CE02070 =="22. In keinem der hier aufgef\xfchrten Bereiche."]<-0	
	unique(gip[,c("competence_spd","CE02070")])	
	
	## count NAs as 0
	gip$competence_spd_nas_as_0 <-1
	gip$competence_spd_nas_as_0[gip$CE02070=="-90. item nonresponse" | gip$CE02070=="-99. wei\xdf nicht/keine Meinung"]<-0
	gip$competence_spd_nas_as_0[is.na(gip$CE02070)]<-0
	gip$competence_spd_nas_as_0[gip$CE02070 =="22. In keinem der hier aufgef\xfchrten Bereiche."]<-0
	unique(gip[,c("competence_spd_nas_as_0","CE02070")])	
	
	table(gip$competence_spd, useNA='always')
	table(gip$competence_spd_nas_as_0, useNA='always')

	## FDP
	unique(gip$CE02071)
	gip$competence_fdp <-1
	gip$competence_fdp[gip$CE02071 =="-90. item nonresponse" | gip$CE02071 =="-99. wei\xdf nicht/keine Meinung"]<-NA
	gip$competence_fdp[is.na(gip$CE02071)]<-NA
	gip$competence_fdp[gip$CE02071 =="22. In keinem der hier aufgef\xfchrten Bereiche."]<-0	
	unique(gip[,c("competence_fdp","CE02071")])	
	
	## count NAs as 0
	gip$competence_fdp_nas_as_0 <-1
	gip$competence_fdp_nas_as_0[gip$CE02071 =="-90. item nonresponse" | gip$CE02071 =="-99. wei\xdf nicht/keine Meinung"]<-0
	gip$competence_fdp_nas_as_0[is.na(gip$CE02071)]<-0
	gip$competence_fdp_nas_as_0[gip$CE02071 =="22. In keinem der hier aufgef\xfchrten Bereiche."]<-0
	unique(gip[,c("competence_fdp_nas_as_0","CE02071")])	
	
	table(gip$competence_fdp, useNA='always')
	table(gip$competence_fdp_nas_as_0, useNA='always')

	
	## Greens
	unique(gip$CE02072)
	gip$competence_greens <-1
	gip$competence_greens[gip$CE02072 =="-90. item nonresponse" | gip$CE02072 =="-99. wei\xdf nicht/keine Meinung"]<-NA
	gip$competence_greens[is.na(gip$CE02072)]<-NA
	gip$competence_greens[gip$CE02072 =="22. In keinem der hier aufgef\xfchrten Bereiche."]<-0	
	unique(gip[,c("competence_greens","CE02072")])	
	
	## count NAs as 0
	gip$competence_greens_nas_as_0 <-1
	gip$competence_greens_nas_as_0[gip$CE02072 =="-90. item nonresponse" | gip$CE02072 =="-99. wei\xdf nicht/keine Meinung"]<-0
	gip$competence_greens_nas_as_0[is.na(gip$CE02072)]<-0
	gip$competence_greens_nas_as_0[gip$CE02072 =="22. In keinem der hier aufgef\xfchrten Bereiche."]<-0
	unique(gip[,c("competence_greens_nas_as_0","CE02072")])	
	
	table(gip$competence_greens, useNA='always')
	table(gip$competence_greens_nas_as_0, useNA='always')
	
	
	## LINKE
	unique(gip$CE02073)
	gip$competence_linke <-1
	gip$competence_linke[gip$CE02073 =="-90. item nonresponse" | gip$CE02073 =="-99. wei\xdf nicht/keine Meinung"]<-NA
	gip$competence_linke[is.na(gip$CE02073)]<-NA
	gip$competence_linke[gip$CE02073 =="22. In keinem der hier aufgef\xfchrten Bereiche."]<-0	
	unique(gip[,c("competence_linke","CE02073")])	
	
	## count NAs as 0
	gip$competence_linke_nas_as_0 <-1
	gip$competence_linke_nas_as_0[gip$CE02073 =="-90. item nonresponse" | gip$CE02073 =="-99. wei\xdf nicht/keine Meinung"]<-0
	gip$competence_linke_nas_as_0[is.na(gip$CE02073)]<-0
	gip$competence_linke_nas_as_0[gip$CE02073 =="22. In keinem der hier aufgef\xfchrten Bereiche."]<-0
	unique(gip[,c("competence_linke_nas_as_0","CE02073")])	
	
	table(gip$competence_linke, useNA='always')
	table(gip$competence_linke_nas_as_0, useNA='always')
	
	
	
	## Government
		
	gip$competence_gov<-NA
	gip$competence_gov[gip$competence_cducsu==0 & gip$competence_fdp==0]<-0
		nas.cducsu<-which(is.na(gip$competence_cducsu))
		fdp_0<-which(gip$competence_fdp==0)
		final<-NA; final<-intersect(nas.cducsu, fdp_0)
	gip$competence_gov[final]<-0
		nas.fdp<-which(is.na(gip$competence_fdp))
		cducsu_0<-which(gip$competence_cducsu==0)
		final<-NA; final<-intersect(nas.fdp, cducsu_0)
	gip$competence_gov[final]<-0
	
	gip$competence_gov[gip$competence_cducsu==1 | gip$competence_fdp==1]<-1
	
	unique(gip[,c("competence_gov","competence_cducsu","competence_fdp")])	
	
	
	gip$competence_gov_nas_as_0<-0
	gip$competence_gov_nas_as_0[gip$competence_cducsu==1 | gip$competence_fdp==1]<-1
	unique(gip[,c("competence_gov_nas_as_0","competence_cducsu","competence_fdp")])	

	
		
		
	## political sophistication - government knowledge	
		
	## voter sophistication - AB02020 (5 cent), 	AB02021 (5 minutes), AB02022 (47 days),
	gip$math_question_ball # ## correct answer 5 cent
	gip$math_question_machines # correct answer 5 minutes
	gip$math_question_carpet # correct answer 47 day

	gip$math_question_ball_correct<-9999999
	gip$math_question_ball_correct[gip$math_question_ball!=5]<-0
	gip$math_question_ball_correct[gip$math_question_ball==5]<-1
	gip$math_question_ball_correct[is.na(gip$math_question_ball)]<-NA
	table(gip$math_question_ball_correct, useNA="always")
	unique(gip[,c("math_question_ball","math_question_ball_correct")])	

		
	gip$math_question_machines_correct<-9999999
	gip$math_question_machines_correct[gip$math_question_machines!=5]<-0
	gip$math_question_machines_correct[gip$math_question_machines ==5]<-1
	gip$math_question_machines_correct[is.na(gip$math_question_machines)]<-NA
	table(gip$math_question_machines_correct, useNA="always")
	unique(gip[,c("math_question_machines","math_question_machines_correct")])	

	
	
	
	gip$math_question_carpet_correct<-9999999
	gip$math_question_carpet_correct[gip$math_question_carpet!=47]<-0
	gip$math_question_carpet_correct[gip$math_question_carpet ==47]<-1
	gip$math_question_carpet_correct[is.na(gip$math_question_carpet)]<-NA
	table(gip$math_question_carpet_correct, useNA="always")
	unique(gip[,c("math_question_carpet","math_question_carpet_correct")])	
	
	
	gip$math_soph<-gip$math_question_ball_correct+gip$math_question_machines_correct+gip$math_question_carpet_correct
	unique(gip[check,c("math_soph","math_question_ball_correct","math_question_machines_correct","math_question_carpet_correct")])	
	table(gip$math_soph, useNA="always")


## political knowledge (from wave 3 (January 2013))

	## electoral treshold
	table(gip$pol_know_election_treshold, useNA="always")
	temp<-NA; temp<-gip$pol_know_election_treshold
	gip$pol_know_election_treshold_dummy<-0
	gip$pol_know_election_treshold_dummy[is.na(temp)]<-NA
	gip$pol_know_election_treshold_dummy[temp==" "]<-0

	gip$pol_know_election_treshold_dummy[temp=="05"]<-1
	gip$pol_know_election_treshold_dummy[temp==">5%"]<-1
	gip$pol_know_election_treshold_dummy[temp=="5,1"]<-1

	gip$pol_know_election_treshold_dummy[temp=="5"]<-1
	gip$pol_know_election_treshold_dummy[temp=="5,0"]<-1
	gip$pol_know_election_treshold_dummy[temp=="5%"]<-1
	unique(gip[,c("pol_know_election_treshold_dummy","pol_know_election_treshold")])
	table(gip$pol_know_election_treshold_dummy, useNA="always")

	## chancelor election
	table(gip$pol_know_chancelor, useNA="always")
	temp<-NA; temp<-gip$pol_know_chancelor
	gip$pol_know_chancelor_dummy<-NA

	gip$pol_know_chancelor_dummy[temp=="1. Die Bundesversammlung"]<-0
	gip$pol_know_chancelor_dummy[temp=="2. Die Abgeordneten im Bundestag"]<-1
	gip$pol_know_chancelor_dummy[temp=="3. Das Volk"]<-0
	gip$pol_know_chancelor_dummy[temp=="4. Die Mitglieder der Bundesregierung"]<-0
	gip$pol_know_chancelor_dummy[temp=="-99. wei\xdf nicht/keine Meinung"]<-0
	unique(gip[,c("pol_know_chancelor","pol_know_chancelor_dummy")])
	table(gip$pol_know_chancelor_dummy, useNA="always")
	
	## politicians	
	table(gip$pol_know_person_leyen_cdu)
	temp<-NA; temp<-gip$pol_know_person_leyen_cdu
	gip$pol_know_person_leyen_cdu_dummy<-NA
	gip$pol_know_person_leyen_cdu_dummy[temp=="-99. wei\xdf nicht/keine Meinung"]<-0
	gip$pol_know_person_leyen_cdu_dummy[temp=="1. CDU"]<-1
	gip$pol_know_person_leyen_cdu_dummy[temp=="2. CSU"]<-0
	gip$pol_know_person_leyen_cdu_dummy[temp=="3. SPD"]<-0
	gip$pol_know_person_leyen_cdu_dummy[temp=="4. FDP"]<-0
	gip$pol_know_person_leyen_cdu_dummy[temp=="5. B\xfcndnis 90/Die Gr\xfcnen"]<-0
	gip$pol_know_person_leyen_cdu_dummy[temp=="6. Die Linke"]<-0
	gip$pol_know_person_leyen_cdu_dummy[temp=="7. keiner der hier aufgef\xfchrten"]<-0
	unique(gip[,c("pol_know_person_leyen_cdu","pol_know_person_leyen_cdu_dummy")])
	table(gip$pol_know_person_leyen_cdu_dummy, useNA="always")
	
	table(gip$pol_know_person_steinbrueck_spd)
	temp<-NA; temp<-gip$pol_know_person_steinbrueck_spd
	gip$pol_know_person_steinbrueck_spd_dummy<-NA
	gip$pol_know_person_steinbrueck_spd_dummy[temp=="-99. wei\xdf nicht/keine Meinung"]<-0
	gip$pol_know_person_steinbrueck_spd_dummy[temp=="1. CDU"]<-0
	gip$pol_know_person_steinbrueck_spd_dummy[temp=="2. CSU"]<-0
	gip$pol_know_person_steinbrueck_spd_dummy[temp=="3. SPD"]<-1
	gip$pol_know_person_steinbrueck_spd_dummy[temp=="4. FDP"]<-0
	gip$pol_know_person_steinbrueck_spd_dummy[temp=="5. B\xfcndnis 90/Die Gr\xfcnen"]<-0
	gip$pol_know_person_steinbrueck_spd_dummy[temp=="6. Die Linke"]<-0
	gip$pol_know_person_steinbrueck_spd_dummy[temp=="7. keiner der hier aufgef\xfchrten"]<-0
	unique(gip[,c("pol_know_person_steinbrueck_spd","pol_know_person_steinbrueck_spd_dummy")])
	
	
	table(gip$pol_know_person_bahr_fdp)
	temp<-NA; temp<-gip$pol_know_person_bahr_fdp
	gip$pol_know_person_bahr_fdp_dummy<-NA
	gip$pol_know_person_bahr_fdp_dummy[temp=="-99. wei\xdf nicht/keine Meinung"]<-0
	gip$pol_know_person_bahr_fdp_dummy[temp=="1. CDU"]<-0
	gip$pol_know_person_bahr_fdp_dummy[temp=="2. CSU"]<-0
	gip$pol_know_person_bahr_fdp_dummy[temp=="3. SPD"]<-0
	gip$pol_know_person_bahr_fdp_dummy[temp=="4. FDP"]<-1
	gip$pol_know_person_bahr_fdp_dummy[temp=="5. B\xfcndnis 90/Die Gr\xfcnen"]<-0
	gip$pol_know_person_bahr_fdp_dummy[temp=="6. Die Linke"]<-0
	gip$pol_know_person_bahr_fdp_dummy[temp=="7. keiner der hier aufgef\xfchrten"]<-0
	unique(gip[,c("pol_know_person_bahr_fdp","pol_know_person_bahr_fdp_dummy")])
		
	table(gip$pol_know_person_gysi_linke)
	temp<-NA; temp<-gip$pol_know_person_gysi_linke
	gip$pol_know_person_gysi_linke_dummy<-NA
	gip$pol_know_person_gysi_linke_dummy[temp=="-99. wei\xdf nicht/keine Meinung"]<-0
	gip$pol_know_person_gysi_linke_dummy[temp=="1. CDU"]<-0
	gip$pol_know_person_gysi_linke_dummy[temp=="2. CSU"]<-0
	gip$pol_know_person_gysi_linke_dummy[temp=="3. SPD"]<-0
	gip$pol_know_person_gysi_linke_dummy[temp=="4. FDP"]<-0
	gip$pol_know_person_gysi_linke_dummy[temp=="5. B\xfcndnis 90/Die Gr\xfcnen"]<-0
	gip$pol_know_person_gysi_linke_dummy[temp=="6. Die Linke"]<-1
	gip$pol_know_person_gysi_linke_dummy[temp=="7. keiner der hier aufgef\xfchrten"]<-0
	unique(gip[,c("pol_know_person_gysi_linke","pol_know_person_gysi_linke_dummy")])
	
	
	table(gip$pol_know_person_trittin_greens)
	temp<-NA; temp<-gip$pol_know_person_trittin_greens
	gip$pol_know_person_trittin_greens_dummy <-NA
	gip$pol_know_person_trittin_greens_dummy[temp=="-99. wei\xdf nicht/keine Meinung"]<-0
	gip$pol_know_person_trittin_greens_dummy[temp=="1. CDU"]<-0
	gip$pol_know_person_trittin_greens_dummy[temp=="2. CSU"]<-0
	gip$pol_know_person_trittin_greens_dummy[temp=="3. SPD"]<-0
	gip$pol_know_person_trittin_greens_dummy[temp=="4. FDP"]<-0
	gip$pol_know_person_trittin_greens_dummy[temp=="5. B\xfcndnis 90/Die Gr\xfcnen"]<-1
	gip$pol_know_person_trittin_greens_dummy[temp=="6. Die Linke"]<-0
	gip$pol_know_person_trittin_greens_dummy[temp=="7. keiner der hier aufgef\xfchrten"]<-0
	unique(gip[,c("pol_know_person_trittin_greens","pol_know_person_trittin_greens_dummy")])
	

	
	## count correct political knowledge questions
	
	
	# sum the correct answers, ignore nas
	gip$pol_know_all<-rowSums(x=gip[,c("pol_know_election_treshold_dummy", "pol_know_chancelor_dummy", "pol_know_person_leyen_cdu_dummy", "pol_know_person_steinbrueck_spd_dummy", "pol_know_person_bahr_fdp_dummy", "pol_know_person_gysi_linke_dummy", "pol_know_person_trittin_greens_dummy")], na.rm=T)

	nas<-NA; nas<-which(is.na(gip$pol_know_election_treshold_dummy) & is.na(gip$pol_know_chancelor_dummy) & is.na(gip$pol_know_person_leyen_cdu_dummy) & is.na(gip$pol_know_person_steinbrueck_spd_dummy) & is.na(gip$pol_know_person_bahr_fdp_dummy) & is.na(gip$pol_know_person_gysi_linke_dummy) & is.na(gip$pol_know_person_trittin_greens_dummy)) 
	gip$pol_know_all[nas]<-NA
	table(gip$pol_know_all, useNA="always")
	
	
	
	unique(gip[,c("pol_know_all","pol_know_election_treshold_dummy", "pol_know_chancelor_dummy", "pol_know_person_leyen_cdu_dummy", "pol_know_person_steinbrueck_spd_dummy", "pol_know_person_bahr_fdp_dummy", "pol_know_person_gysi_linke_dummy", "pol_know_person_trittin_greens_dummy")])


	test<-which(gip$pol_know_all==0)

		unique(gip[test,c("pol_know_all","pol_know_election_treshold_dummy", "pol_know_chancelor_dummy", "pol_know_person_leyen_cdu_dummy", "pol_know_person_steinbrueck_spd_dummy", "pol_know_person_bahr_fdp_dummy", "pol_know_person_gysi_linke_dummy", "pol_know_person_trittin_greens_dummy")])
	



	library("Hmisc")
	table( gip$math_soph,gip$pol_know_all )

	rcorr(x=gip$pol_know_all, gip$math_soph, type="pearson")


	## policy failure responsibility
	
	unique(gip$gridlock_resp)
	gip$gridlock_resp_gov<-NA
	gip$gridlock_resp_gov[gip$gridlock_resp=="1. Die Bundeskanzlerin"]<-1
	gip$gridlock_resp_gov[gip$gridlock_resp=="2. Die Koalitionsparteien"]<-1
	gip$gridlock_resp_gov[gip$gridlock_resp=="3. Die Oppositionsparteien"]<-0
	gip$gridlock_resp_gov[gip$gridlock_resp=="4. Die L\xe4nder im Bundesrat"]<-0
	gip$gridlock_resp_gov[gip$gridlock_resp=="5. Das Bundesverfassungsgericht"]<-0
	gip$gridlock_resp_gov[gip$gridlock_resp=="7. Alle gleicherma\xdfen"]<-0
	gip$gridlock_resp_gov[gip$gridlock_resp=="8. Keiner der hier aufgef\xfchrten"]<-0
	gip$gridlock_resp_gov[gip$gridlock_resp=="-90. item nonresponse"]<-NA
	gip$gridlock_resp_gov[gip$gridlock_resp=="-99. wei\xdf nicht/keine Meinung"]<-NA
	unique(gip[,c("gridlock_resp_gov","gridlock_resp")])



### Income

unique(gip$AA01054)

gip$income <-NA
gip$income[gip$AA01054=="1. unter 150 Euro"]<-1
gip$income[gip$AA01054=="2. 150 bis unter 400 Euro"]<-150
gip$income[gip$AA01054=="3. 400 bis unter 1000 Euro"]<-400
gip$income[gip$AA01054=="4. 1000 bis unter 1500 Euro"]<-1000
gip$income[gip$AA01054=="5. 1500 bis unter 2000 Euro"]<-1500
gip$income[gip$AA01054=="6. 2000 bis unter 2500 Euro"]<-2000
gip$income[gip$AA01054=="7. 2500 bis unter 3000 Euro"]<-2500
gip$income[gip$AA01054=="8. 3000 bis unter 3500 Euro"]<-3000
gip$income[gip$AA01054=="9. 3500 bis unter 4000 Euro"]<-3500
gip$income[gip$AA01054=="10. 4000 bis unter 4500 Euro"]<-4000
gip$income[gip$AA01054=="11. 4500 bis unter 5000 Euro"]<-4500
gip$income[gip$AA01054=="12. 5000 bis unter 5500 Euro"]<-5000
gip$income[gip$AA01054=="13. 5500 bis unter 6000 Euro"]<-5500
gip$income[gip$AA01054=="14. 6000 bis unter 7500 Euro"]<-6000
gip$income[gip$AA01054=="15. 7500 Euro und mehr"]<-7500

gip$income_cat<-NA
gip$income_cat[gip$AA01054=="1. unter 150 Euro"]<-1
gip$income_cat[gip$AA01054=="2. 150 bis unter 400 Euro"]<-2
gip$income_cat[gip$AA01054=="3. 400 bis unter 1000 Euro"]<-3
gip$income_cat[gip$AA01054=="4. 1000 bis unter 1500 Euro"]<-4
gip$income_cat[gip$AA01054=="5. 1500 bis unter 2000 Euro"]<-5
gip$income_cat[gip$AA01054=="6. 2000 bis unter 2500 Euro"]<-6
gip$income_cat[gip$AA01054=="7. 2500 bis unter 3000 Euro"]<-7
gip$income_cat[gip$AA01054=="8. 3000 bis unter 3500 Euro"]<-8
gip$income_cat[gip$AA01054=="9. 3500 bis unter 4000 Euro"]<-9
gip$income_cat[gip$AA01054=="10. 4000 bis unter 4500 Euro"]<-10
gip$income_cat[gip$AA01054=="11. 4500 bis unter 5000 Euro"]<-11
gip$income_cat[gip$AA01054=="12. 5000 bis unter 5500 Euro"]<-12
gip$income_cat[gip$AA01054=="13. 5500 bis unter 6000 Euro"]<-13
gip$income_cat[gip$AA01054=="14. 6000 bis unter 7500 Euro"]<-14
gip$income_cat[gip$AA01054=="15. 7500 Euro und mehr"]<-15



unique(gip[,c("income","income_cat","AA01054")])

gip$income_log<-log(gip$income)
unique(gip[,c("income","income_cat","income_log","AA01054")])

## 	## CDU/CSU Economy competence
	gip$CE02069 # cducsu
	unique(gip$CE02069)
	gip$competence_econ_cducsu<-0
	gip$competence_econ_cducsu[gip$CE02069=="19. Wirtschaft"]<-1
	gip$competence_econ_cducsu[gip$CE02069=="-90. item nonresponse" | gip$CE02069=="-99. wei\xdf nicht/keine Meinung"]<-NA
	gip$competence_econ_cducsu[is.na(gip$CE02069)]<-NA
	gip$competence_econ_cducsu[gip$CE02069=="22. In keinem der hier aufgef\xfchrten Bereiche."]<-0	
	unique(gip[,c("competence_econ_cducsu","CE02069")])	
	
	## count NAs as 0	
	gip$competence_econ_cducsu_nas_as_0<-0
	gip$competence_econ_cducsu_nas_as_0[gip$CE02069=="19. Wirtschaft"]<-1
	
	unique(gip[,c("competence_econ_cducsu_nas_as_0","CE02069")])	

	
## FDP Econ competence
	unique(gip$CE02071)
	gip$competence_econ_fdp <-0
	gip$competence_econ_fdp[gip$CE02071=="19. Wirtschaft"]<-1
	gip$competence_econ_fdp[gip$CE02071 =="-90. item nonresponse" | gip$CE02071 =="-99. wei\xdf nicht/keine Meinung"]<-NA
	gip$competence_econ_fdp[is.na(gip$CE02071)]<-NA
	gip$competence_econ_fdp[gip$CE02071 =="22. In keinem der hier aufgef\xfchrten Bereiche."]<-0	
	unique(gip[,c("competence_econ_fdp","CE02071")])	
	
	## count NAs as 0
	gip$competence_econ_fdp_nas_as_0 <-0
	gip$competence_econ_fdp_nas_as_0[gip$CE02071=="19. Wirtschaft"]<-1
		unique(gip[,c("competence_econ_fdp_nas_as_0","CE02071")])	
	


## Government competence econ
		
	gip$competence_econ_gov<-NA
	gip$competence_econ_gov[gip$competence_econ_cducsu==0 & gip$competence_econ_fdp==0]<-0
		econ.nas.cducsu<-which(is.na(gip$competence_econ_cducsu))
		econ.fdp_0<-which(gip$competence_econ_fdp==0)
		final<-NA; final<-intersect(econ.nas.cducsu, econ.fdp_0)
	gip$competence_econ_gov[final]<-0
		econ.nas.fdp<-which(is.na(gip$competence_econ_fdp))
		econ.cducsu_0<-which(gip$competence_econ_cducsu==0)
		final<-NA; final<-intersect(econ.nas.fdp, econ.cducsu_0)
	gip$competence_econ_gov[final]<-0
	
	gip$competence_econ_gov[gip$competence_econ_cducsu==1 | gip$competence_econ_fdp==1]<-1
	
	unique(gip[,c("competence_econ_gov","competence_econ_cducsu","competence_econ_fdp")])	
	
	
	gip$competence_econ_gov_nas_as_0<-0
	gip$competence_econ_gov_nas_as_0[gip$competence_econ_cducsu==1 | gip$competence_econ_fdp==1]<-1
	unique(gip[,c("competence_econ_gov_nas_as_0","competence_econ_cducsu","competence_econ_fdp")])	


	
	## union: AA01034
	gip$union<-NA
	gip$union[gip$AA01034=="1. Ich bin kein Mitglied."]<-0
	gip$union[gip$AA01034=="2. Ich bin passives Mitglied."]<-1
	gip$union[gip$AA01034=="3. Ich bin aktives Mitglied."]<-2
	
	gip$union_dummy<-gip$union
	gip$union_dummy[gip$union==2]<-1	
	
	
###-------------------------------------------------------------------
## Save final dataset
###-------------------------------------------------------------------
		
	save(gip,file="./gip_data/gip.rda")

	grep("\\.", names(gip))
	names(gip)[grep("\\.", names(gip))]


## Notes
## ‑99	„weiß nicht“, bzw. Antwortverweigerung mangels Kenntnis
## ‑98	„möchte ich nicht sagen“, bzw. explizite Antwortverweigerung
## ‑97	„trifft nicht zu“, bzw. Antwortverweigerung mangels Anwendbarkeit
## ‑90	implizite Antwortverweigerung (Itemnonreponse): Frage wurde gezeigt, aber nicht beantwortet
## Systemfehende Werte (Lücken) finden sich im Datensatz, wenn Fragen nicht angezeigt wurden (z. B. wegen Filter oder Experimentalbedingung oder weil Befragte vorher die Teilnahme abgebrochen haben).



## save dataset in stata

	#write_dta(gip, "./gip_data/gip.dta")		
	write.dta(gip, "./gip_data/gip.dta")		


