##@@@------------------------------------------------------------------------------------------------------------------------------------------------
## Replication fille for descriptives table
## All analyses are based on survey data from wave 1 and 2 from the German Internet Panel (GIP), which is provided by GESIS. To get the raw data check replication_file_get_data.R
## For further information please contact Mariyana Angelova: mariyana.angelova@univie.ac.at  OR mariyana.angelova@gmail.com
## 11.10.2018
##@@@------------------------------------------------------------------------------------------------------------------------------------------------

## run after "2_main_analyses_TABLE 3.2, 3.3, 3.4, FIGURE 3.1.R"



##------------------------------
## DESCRIPTIVES
##------------------------------

## Create descriptives tavle
## define relevant variables for descriptive table
	
		var<-gip[ ,c
	("gridlock_resp_gov",
	"gov_conflict",
	"cducsu_conflict",
	"fdp_conflict",
	"lr_gov_distance",
	"vote_intention_cducsu",
	"vote_le_gov",
	"vote_le3",
	"econ_decline",
	"policy_discr_all",
	"satisfaction_gov",
	"competence_gov_nas_as_0",
	"competence_cducsu_nas_as_0",
	"competence_fdp_nas_as_0",
	"lr_self",
	"age_cat",
	"woman",
	"education",
	"religion_activity",
	"pol_know_all",
	"family_satisfaction",
	"financial_satisfaction",
	"leisure_satisfaction",
	"gov_knowledge_cducsu_fdp"
)]
	
	
	
	unique(gip[,c("gov_knowledge_cducsu_fdp","gov_knowledge_cducsu","gov_knowledge_fdp")])


	## check structure of variables
	str(var,useNA="always")

	
	## create an empty object with all variables for which we will get the descriptive information
	descr<-matrix(NA,dim(var)[2],8)
	colnames(descr)<-c(names(summary(var[,1])), "sd")
	rownames(descr)<-names(var)
	
	## calculate descriptive info

	for(i in 1: dim(var)[2]){
	
	summary<-summary(var[,i])
	sd<-sd(var[,i], na.rm=TRUE)
		combine<-NA; 
		if(length(summary)==7) {combine<-round(c(as.vector(summary), sd),digits=2)}
		if(length(summary)==6) {combine<-round(c(as.vector(summary), 0,sd),digits=2)}
		descr[i,]<-combine
	
	} # close for i loop


	descr
	xtable(descr)

	## reorganize columns
	descr.full<-descr[,c(1:6,8,7)] ## full information
	#descr.short_<-descr[,c(1,3,4,6,8,7)] ## only selected information
	descr.short<-descr[,c(4,8,1,6,7)] ## only selected information

	# TABLE 3.1
	descr.short
	# Latex code
  xtable(descr.short)

	## since religion and last vote are factor and not numeric variables, use this descriptive information
	table(gip$religion_activity, useNA="always") # 1= not a member, 2= passive member, 3= active member in a religious community
	table(gip$vote_le3, useNA="always") # cdu/csu, fdp, opposition
	table(gip$gov_knowledge_cducsu_fdp, useNA="always") # cdu/csu, fdp, opposition
