## Angelova (2018) Dissertation Chapter 3: Coalition Conflict - a Remedy for Democratic Accountability?
### Replication of Models 6-7 (Table 3.2), and models 10-11 (Table 3.3) with economic decline coded as a dichotomuous variable:


### Before running this script run the following R script to get GIP data provided via Gesis: source('./1_replication_file_get_data.R')



## set working directory
setwd("~/Documents/Dissertation/Diss - Replication - Chapter 3")

## clean working space
rm(list = ls(all = TRUE))

print(sessionInfo())

## get packages
library("Zelig")
library("mlogit")
library("nnet")
library("memisc")
library("stargazer")
library("xtable")
library("texreg")
library("stargazer")
library("Hmisc")
library("MASS")

## get gip data

load(file="./gip_data/gip.rda") # this data is created in script ./1_replication_file_get_data.R
gip.backup<-gip
dim(gip.backup)
options(signif.symbols=c("***"=.001,"**"=.01,"*"=.05,"'"=.1))

## run additional variable modifications
source('./var_modifications.R')

gip$vote_le3_orig<-as.factor(gip$vote_last_election_cducsu_fdp_opp)
gip$vote_le3<-relevel(gip$vote_le3_orig, ref="opposition")

## keep only respondents from second wave
gip<-gip[gip$gip2==1,]


## select only these who know that FDP and CDU/CSU are gov parties
gip.know.cducsu.fdp<-gip[ gip$gov_knowledge_fdp==1 & gip$gov_knowledge_cducsu==1,]
gip.know.cducsu<-gip[gip$gov_knowledge_cducsu==1,]
gip.know.fdp<-gip[ gip$gov_knowledge_fdp==1,]

dim(gip)


## Replication of models 6,7 and 10,11

unique(gip[,c("econ_decline_dummy","econ_decline","economic_improvement_exp","CE02055")])
	


##------------------------------------------------------------
## Replication of Model 5, 6, 7  Government Ratings 
##------------------------------------------------------
	
## Models presented in Appendix B in Table B1
	
## Replication of Model 5 with economic decline dummy
  gov_rating_economy_s1<-zelig(satisfaction_gov ~ econ_decline_dummy +gov_conflict+cducsu_conflict + fdp_conflict + vote_le_gov+ competence_gov_nas_as_0 + age_cat + woman + education + religion_activity + family_satisfaction +financial_satisfaction+ leisure_satisfaction+ pol_know_all, model="ls", data=gip.know.cducsu.fdp); summary(gov_rating_economy_s1) 
	
		
## Replication of Model 7 with economic decline dummy
  gov_rating_economy<-zelig(satisfaction_gov ~ econ_decline_dummy*gov_conflict*vote_le_gov+cducsu_conflict + fdp_conflict+ competence_gov_nas_as_0+ age_cat + woman + education + religion_activity + family_satisfaction +financial_satisfaction+ leisure_satisfaction+ pol_know_all, model="ls", data=gip.know.cducsu.fdp,cite=F);  summary(gov_rating_economy)
    
    
    model1<-gov_rating_economy_s1
    model2<-gov_rating_economy

##----------------------------------------------------------------------------------------------
## Replication of Model 10 & 11: CDU/CSU Voting, with economic decline as dichotomous variable
##----------------------------------------------------------------------------------------------
						
	cducsu_voting_economy_s <-zelig(vote_intention_cducsu ~ econ_decline_dummy+gov_conflict+ vote_le3 + cducsu_conflict + competence_cducsu_nas_as_0+ age_cat + woman + education + religion_activity + family_satisfaction + financial_satisfaction + leisure_satisfaction+ pol_know_all, model="logit", data= gip.know.cducsu) ; summary(cducsu_voting_economy_s)
    
	cducsu_voting_economy <-zelig(vote_intention_cducsu ~ econ_decline_dummy* gov_conflict* vote_le3 + cducsu_conflict + competence_cducsu_nas_as_0+ age_cat + woman + education + religion_activity + family_satisfaction + financial_satisfaction + leisure_satisfaction+ pol_know_all, model="logit", data= gip.know.cducsu) ; summary(cducsu_voting_economy)
	  
	
	  model3<-cducsu_voting_economy_s
  	model4<-cducsu_voting_economy

##==============================================================================================================================
## GET Table B1 from Appendix B	
##==============================================================================================================================
	table.b1.appendix<-list(model1,model2,model3,model4)
	screenreg(table.b1.appendix, digits=3)
	texreg(table.b1.appendix, digits=3)
	
##==============================================================================================================================
## Get substantve effect of economic decline (dummy) on government ratings and  CDU/CSU voting presented in Figure B.1, Appendix B
##==============================================================================================================================
	

	## Set values
	c.min<-min(gip$gov_conflict, na.rm=T)
	c.max<-max(gip$gov_conflict, na.rm=T)
	q10.conflict<-quantile(gip$gov_conflict, prob=c(0.1), na.rm=T)
	q90.conflict<-quantile(gip$gov_conflict, prob=c(0.9), na.rm=T)
	#q05.conflict<-quantile(gip$gov_conflict, prob=c(0.05), na.rm=T)
	#q95.conflict<-quantile(gip$gov_conflict, prob=c(0.95), na.rm=T)
	c.low<-q10.conflict
	c.hi<-q90.conflict
	gov.c<-seq(c.min, c.max,length.out=50)
	
	
	##==============================================================================================================================
	## Substantive Effect (shift from 0 to 1) of eonomic decline on government ratings for different values of coalition conflict
	##============================================================================================================================
	mod<-gov_rating_economy		
	
	## GOV SUPPORTERS: marginal effect of econ
	vote.gov <-NA;vote.gov<-1
	modx<-setx(mod, vote_le_gov = vote.gov, gov_conflict= gov.c, woman =0, econ_decline_dummy = 0  )
	mods<-sim(mod, modx, num=10000)
	res<-NA; res<-get_qi(mods, xvalue="range")
	res<-as.data.frame(res); names(res)<-1:50
	me1_gov <-NA; me1_gov<-res	# econ decline low
	
	modx<-setx(mod, vote_le_gov = vote.gov, gov_conflict= gov.c, woman =0, econ_decline_dummy = 1 )
	mods<-sim(mod, modx, num=10000)
	res<-NA; res<-get_qi(mods, xvalue="range")
	res<-as.data.frame(res); names(res)<-1:50
	me2_gov <-NA; me2_gov <-res	# econ decline high
	
	me_gov<-me2_gov-me1_gov
	
	
	
	## OPP SUPPORTERS: marginal effect of econ 
	vote.gov <-NA; vote.gov<-0
	modx<-setx(mod, vote_le_gov = vote.gov, gov_conflict= gov.c, woman =0, econ_decline_dummy = 0  )
	mods<-sim(mod, modx, num=10000)
	res<-NA; res<-get_qi(mods, xvalue="range")
	res<-as.data.frame(res); names(res)<-1:50
	me1_opp<-NA; me1_opp<-res	# econ decline low
	
	modx<-setx(mod, vote_le_gov = vote.gov, gov_conflict= gov.c, woman =0, econ_decline_dummy = 1 )
	mods<-sim(mod, modx, num=10000)
	res<-NA; res<-get_qi(mods, xvalue="range")
	res<-as.data.frame(res); names(res)<-1:50
	me2_opp <-NA; me2_opp <-res	# econ decline high
	
	me_opp<-me2_opp-me1_opp
	
	## save substantive effect of economic decline on government ratings in separate objects (will need this to plot figure B1 in the appendix )
	me_gov_gov.r_econ<-me_gov
	me_opp_gov.r_econ<-me_opp
	
	
	
##==============================================================================================================================
## Substantive Effect (shift from 0 to 1) of eonomic decline on CDU/CSU ratings for different values of coalition conflict
##==============================================================================================================================
	
		mod<-cducsu_voting_economy

	
	## CDUCSU SUPPORTERS: marginal effect of econ 
				
		modx<-setx(mod, vote_le3 = "cducsu", gov_conflict= gov.c, woman =0, econ_decline_dummy = 0)
		mods<-sim(mod, modx, num=10000)
		res<-NA; res<-get_qi(mods, xvalue="range")
		res<-as.data.frame(res); names(res)<-1:50
		me1_gov <-NA; me1_gov<-res	# econ decline low
		
		modx<-setx(mod, vote_le3 = "cducsu", gov_conflict= gov.c, woman =0, econ_decline_dummy = 1 )
		mods<-sim(mod, modx, num=10000)
		res<-NA; res<-get_qi(mods, xvalue="range")
		res<-as.data.frame(res); names(res)<-1:50
		me2_gov <-NA; me2_gov <-res	# econ decline high

		## get substantive effect: difference between the predicted proabilities when economic decline is 1 and 0 (cducsu supporters)
		me_gov <-NA; me_gov<-me2_gov-me1_gov

	
		## Opp SUPPORTERS: marginal effect of econ
		modx<-setx(mod, vote_le3 = "opposition", gov_conflict= gov.c, woman =0, econ_decline_dummy =0 )
		mods<-sim(mod, modx, num=10000)
		res<-NA; res<-get_qi(mods, xvalue="range")
		res<-as.data.frame(res); names(res)<-1:50
		me1_opp <-NA; me1_opp<-res	# econ decline low
		
		modx<-setx(mod, vote_le3 = "opposition", gov_conflict= gov.c, woman =0, econ_decline_dummy =1 )
		mods<-sim(mod, modx, num=10000)
		res<-NA; res<-get_qi(mods, xvalue="range")
		res<-as.data.frame(res); names(res)<-1:50
		me2_opp <-NA; me2_opp <-res	# econ decline high

		me_opp <-NA; me_opp<-me2_opp-me1_opp
	
		## save substantive effects in seperate objects, will need them to plot figure B1 (Appendix)
		me_cducsu_cducsu.v_econ<-me_gov
		me_opp_cducsu.v_econ<-me_opp
	
##----------------------------------------------------
## Plot Figure B.1 (Appendix)
##----------------------------------------------------
		
		pdf(file="./robustness checks/graphs/figureB.1_appendix_econ_dummy.pdf", bg="transparent",width=6, height=7.2) # 8, 6.5

		par(mfrow=c(2,2))
		par(oma=c(2,2,2,2))
		par(mar=c(5,4,5,1))
			
	 plot(y=c(-4,+2), x=c(c.low,c.hi), type="n", xlab="Coalition Conflict", ylab="Effect on Gov Ratings", las=1, main="", cex.main=1.1) 
        mtext(text="Gov Supporters",side=3, line=0.5, cex=0.8, font=2)
			  lines(x= gov.c,y=apply(me_gov_gov.r_econ,2, mean), lwd=2, col="black")
			  lines(x= gov.c,y=apply(me_gov_gov.r_econ,2, quantile,prob=0.025), lwd=1, col="black", lty=2)
			  lines(x= gov.c,y=apply(me_gov_gov.r_econ,2, quantile,prob=0.975), lwd=1, col="black", lty=2)
				abline(h=0, col="red")
				mtext(text="Impact of Economic Decline (Dummy) on Government Ratings", side=3, line=3, at=10, outer=F)

    plot(y=c(-4,+2), x=c(c.low,c.hi), type="n", xlab="Coalition Conflict", ylab="Effect on Gov Ratings", las=1, main="", cex.main=1.1) 
        mtext(text="Opp Supporters",side=3, line=0.5, cex=0.8, font=2)
			  lines(x= gov.c,y=apply(me_opp_gov.r_econ,2, mean), lwd=2, col="gray")
			  lines(x= gov.c,y=apply(me_opp_gov.r_econ,2, quantile,prob=0.025), lwd=1, col="gray", lty=2)
			  lines(x= gov.c,y=apply(me_opp_gov.r_econ,2, quantile,prob=0.975), lwd=1, col="gray", lty=2)
				abline(h=0, col="red")

	  plot(y=c(-0.8,+0.4), x=c(c.low,c.hi), type="n", xlab="Coalition Conflict", ylab="Effect on CDU/CSU Voting", las=1, main="", cex.main=1.1) 
        mtext(text="CDU/CSU Supporters",side=3, line=0.5, cex=0.8, font=2)
			  lines(x= gov.c,y=apply(me_cducsu_cducsu.v_econ,2, mean), lwd=2, col="black")
			  lines(x= gov.c,y=apply(me_cducsu_cducsu.v_econ,2, quantile,prob=0.025), lwd=1, col="black", lty=2)
			  lines(x= gov.c,y=apply(me_cducsu_cducsu.v_econ,2, quantile,prob=0.975), lwd=1, col="black", lty=2)
				abline(h=0, col="red")
				mtext(text="Impact of Economic Decline (Dummy) on CDU/CSU Vote", side=3, line=3,at=10, outer=F)
	
	  plot(y=c(-0.6,+0.5), x=c(c.low,c.hi), type="n", xlab="Coalition Conflict", ylab="Effect on CDU/CSU Voting", las=1, main="", cex.main=1.1) 
        mtext(text="Opp Supporters",side=3, line=0.5, cex=0.8, font=2)
			  lines(x= gov.c,y=apply(me_opp_cducsu.v_econ,2, mean), lwd=2, col="gray")
			  lines(x= gov.c,y=apply(me_opp_cducsu.v_econ,2, quantile,prob=0.025), lwd=1, col="gray", lty=2)
			  lines(x= gov.c,y=apply(me_opp_cducsu.v_econ,2, quantile,prob=0.975), lwd=1, col="gray", lty=2)
				abline(h=0, col="red")

dev.off()











