## Replication of Model 11 and Model 13 (vote for CDU/CSU with three fold interaction between last vote, coalition conflict, and policy dissatsifaction (econ, 20 policy areas) with multinomial logit models
## only those respondents who know that CDU/CSU was a government party

## before running this script run script "1_replication_file_get_data.R"

## clean working space
	rm(list = ls(all = TRUE))
	

library("MASS")
## get packages
library("Zelig") # work computer 4.2-1
library("mlogit")
library("nnet")
library("memisc")
library("stargazer")
library("xtable")
library("texreg")
library("stargazer")
library("Hmisc")
#install.packages("ZeligChoice")
library("ZeligChoice")
#install.packages("ZeligMultilevel")
library("ZeligMultilevel")
library(zeligverse)
#install.packages("zeligverse")


	## get gip data
	
	load(file="./gip_data/gip.rda") # this data is created in script ./1_replication_file_get_data.R
	gip.backup<-gip
	dim(gip.backup)
	options(signif.symbols=c("***"=.001,"**"=.01,"*"=.05,"'"=.1))
	
	## run additional variable modifications
	source('./var_modifications.R')
	
	gip$vote_le3_orig<-as.factor(gip$vote_last_election_cducsu_fdp_opp)
	gip$vote_le3<-relevel(gip$vote_le3_orig, ref="opposition")
	
	

  ## modify some variables  
  ## last vote
 
    gip$vote_le_all<-gip$vote_last_election_adj
    gip$vote_le_all[gip$vote_last_election_adj=="pirates"]<-"other"
    gip$vote_le_all[gip$vote_last_election_adj=="npd"]<-"other"
    table(gip$vote_le_all, gip$vote_last_election_adj)   

  ## intended vote  
    gip$vote_int<-gip$vote_intention
    gip$vote_int[gip$vote_intention=="npd"]<-"other"
    gip$vote_int[gip$vote_intention=="pirates"]<-"other"
    table(gip$vote_int, gip$vote_intention)   
    
    
    
   ## keep only respondents from second wave
    gip<-gip[gip$gip2==1,]
    
    
## select only these who know that FDP and CDU/CSU are gov parties
    gip.know.cducsu.fdp<-gip[ gip$gov_knowledge_fdp==1 & gip$gov_knowledge_cducsu==1,]
    gip.know.cducsu<-gip[gip$gov_knowledge_cducsu==1,]
    gip.know.fdp<-gip[ gip$gov_knowledge_fdp==1,]
    gip.full<-gip

   
   
    ## keep only those who know that cducsu are gov parties
    gip<-gip.know.cducsu
    

## create dataset for multinomial logit
  ## variables: 
      ## dv: vote choice - 5 parties
      ## INDIVIDUAL specific 
        ## governmetn conflict
        ## economic dec;ine
        ## policy dissatisfaction
    
        ## political knowledge
        ## age, gender, education, religion, satisfactions
    
      ## CHOICE specific
        ## last vote
        ## party conflict
        ## party competence
    
    
   
   data<-gip[,c(
  ## Individual specific variables
  
  "id_g_gip1","vote_int","econ_decline","policy_discr_all","gov_conflict","age_cat", "woman", "education", "religion_activity", "family_satisfaction", "financial_satisfaction","leisure_satisfaction","pol_know_all", "gov_knowledge_cducsu",
  
  ## choice specific variables
  "cducsu_conflict",
  "spd_conflict",
  "fdp_conflict",
  "gruene_conflict",
  "linke_conflict",
  
  "competence_cducsu_nas_as_0",
  "competence_spd_nas_as_0",
  "competence_fdp_nas_as_0",
  "competence_greens_nas_as_0",
  "competence_linke_nas_as_0",
  
  "vote_le_cducsu",
  "vote_le_spd",
  "vote_le_fdp",
  "vote_le_greens",
  "vote_le_linke"

  )]
   
   
    unique(gip[,c("vote_le_all","vote_le_cducsu","vote_le_spd","vote_le_fdp","vote_le_greens","vote_le_linke")])
dim(data)
head(data)


## set other to NA on vote intention
  data$vote_int[data$vote_int=="other"]<-NA
  table(data$vote_int, useNA="always")
  data$vote_int<-as.factor(data$vote_int)
  
  
  
 ## change variable names
  ind.spec.names<-names(data)[1:14]
  old.names<-names(data)
  names(data)<-c(ind.spec.names,
               "conflict.cducsu","conflict.spd","conflict.fdp", "conflict.greens","conflict.linke",
               "competence.cducsu","competence.spd","competence.fdp", "competence.greens","competence.linke",
               "vote_le.cducsu","vote_le.spd","vote_le.fdp", "vote_le.greens","vote_le.linke")
            
  ## control names
  cbind(names(data), old.names)
  
  
  ## define NA cases
  nas<-which(rowSums(is.na(data))>0)
  length(nas)
## delete NA cases
  data.with.nas<-data
  data<-data[-nas,]


## create dataset
str(data)
names(data)
mdata <- mlogit.data(data, shape="wide",  choice="vote_int",varying=15:29)
head(mdata)
  
  
  save(mdata, file="./mlogit/mdata_know.cducsu.rda")
  
  ###################  ###################
  ###################  ###################
  ###################  ###################

	## last vote is only in the choice specific part and enters the individual part only through an interaction
	res_econ<-mlogit(vote_int~ vote_le+conflict+competence | I(econ_decline*gov_conflict) + econ_decline + gov_conflict + I(vote_le*econ_decline) + I(vote_le*gov_conflict) + I(vote_le*econ_decline*gov_conflict)+age_cat+woman+education+family_satisfaction+financial_satisfaction+leisure_satisfaction+ religion_activity+ pol_know_all, mdata, reflevel="spd") 
  
  res_econ_t<-mlogit(vote_int~ vote_le+conflict+competence | I(econ_decline*gov_conflict) + econ_decline + gov_conflict + I(vote_le*econ_decline) + I(vote_le*gov_conflict) + I(vote_le*econ_decline*gov_conflict)+age_cat+woman+education+family_satisfaction+financial_satisfaction+leisure_satisfaction+ religion_activity+ pol_know_all, mdata, reflevel="spd",alt.subset=c("cducsu","linke","greens","spd")) ## miss the fdp as an option 

  summary(res_econ)
  
  #Hausman-McFadden test for independence of irrelevant alternatives
  hmftest(res_econ,res_econ_t) ## p-value is 0.85
  
	res_pa<-mlogit(vote_int~ vote_le+conflict+competence | I(policy_discr_all*gov_conflict) + policy_discr_all + gov_conflict + I(vote_le*policy_discr_all) + I(vote_le*gov_conflict) + I(vote_le* policy_discr_all*gov_conflict)+age_cat+woman+education+family_satisfaction+financial_satisfaction+leisure_satisfaction+ religion_activity+ pol_know_all, mdata, reflevel="spd") ; summary(res_pa)

res_pa_t<-mlogit(vote_int~ vote_le+conflict+competence | I(policy_discr_all*gov_conflict) + policy_discr_all + gov_conflict + I(vote_le*policy_discr_all) + I(vote_le*gov_conflict) + I(vote_le* policy_discr_all*gov_conflict)+age_cat+woman+education+family_satisfaction+financial_satisfaction+leisure_satisfaction+ religion_activity+ pol_know_all, mdata, reflevel="spd",alt.subset=c("cducsu","linke","greens","spd")) 
  
  #Hausman-McFadden test for independence of irrelevant alternatives
  hmftest(res_pa,res_pa_t) ## p-value is 1

##-----------------------------------------------------
## SHOW results presented in TABLE B.3 and TABLE B.4
##-----------------------------------------------------
  
screenreg(list(res_econ,res_pa))
texreg(list(res_econ,res_pa))

mdata$rows<-rownames(mdata)
	

## economic decline
res2<-res_econ




parties<-c("cducsu","fdp","spd","greens","linke")
		pp.Lcon.cducsu<-NA
		pp.Hcon.cducsu<-NA		
		pp.Lcon.spd <-NA
		pp.Hcon.spd <-NA		
		pp.Lcon.fdp <-NA
		pp.Hcon.fdp <-NA		
		pp.Lcon.greens <-NA
		pp.Hcon.greens <-NA		
		pp.Lcon.linke <-NA
		pp.Hcon.linke <-NA		
	

	for(i in 1:5){
		
	
	## set partisanship
	party.supporter<-NA
	party.supporter<-parties[i]



	### PP for ECON (econ, set conflict to 9)
	
	## HIGH COALITION CONFLICT 
	    econ<-seq(0,4, length.out=50)

	    ## set x values
	    sim.econ.hcon<-with(mdata,
                expand.grid(alt = unique(alt),
                           econ_decline =econ,
                            gov_conflict = 9 ,
                            vote_le = 1,
                            conflict = mean(conflict), 
                            competence=max(competence), 
                             age_cat= mean(age_cat),
                            woman=0,
                            education=mean(education),
                            religion_activity=data$religion_activity[1],
                            family_satisfaction=mean(family_satisfaction),
                            financial_satisfaction=mean(financial_satisfaction),
                            leisure_satisfaction=mean(leisure_satisfaction),
                            pol_know_all=mean(pol_know_all)                                                                                                
               			 ))
	    ## set party supporter equal to party.supporter
	    sim.econ.hcon$vote_le[sim.econ.hcon$alt!= party.supporter]<-0
	
	    ## get predicted probabilities for the given X vector
	    pp.hcon2<-predict(res2,sim.econ.hcon)
	
		
  ## LOW COALITION CONFLICT 
	    
	    # define X
	    sim.econ.lcon<-sim.econ.hcon
	    sim.econ.lcon$gov_conflict<-4
	
	    ## get predicted probabilties for X
	    pp.lcon2<-predict(res2, sim.econ.lcon)
	

	## Save predicted probabilities for each party supporter
	
	if(party.supporter=="cducsu"){
		pp.Lcon.cducsu<-pp.lcon2
		pp.Hcon.cducsu<-pp.hcon2		
	}
	
	if(party.supporter=="spd"){
		pp.Lcon.spd <-pp.lcon2
		pp.Hcon.spd <-pp.hcon2		
	}
	
	
		if(party.supporter=="fdp"){
		pp.Lcon.fdp <-pp.lcon2
		pp.Hcon.fdp <-pp.hcon2		
	}
	
		if(party.supporter=="greens" ){
		pp.Lcon.greens <-pp.lcon2
		pp.Hcon.greens <-pp.hcon2		
	}
	
	
		if(party.supporter=="linke"){
		pp.Lcon.linke <-pp.lcon2
		pp.Hcon.linke <-pp.hcon2		
	}
	
	} # close i loop


  ##---------------------------------------------------------------------------------------------------------------------
	## save predicted probabilities to vote for CDU/CSU for different party supporters (CDU/CSU, FDP, SPD, Greens, Linke)
	##---------------------------------------------------------------------------------------------------------------------	
	
	## impact of economic decline for different government supporters (LOW CONFLICT)
	pp.Lcon.econ.by.party<-cbind(pp.Lcon.cducsu[,"cducsu"],pp.Lcon.spd[,"cducsu"],pp.Lcon.fdp[,"cducsu"],pp.Lcon.greens[,"cducsu"],pp.Lcon.linke[,"cducsu"])
	colnames(pp.Lcon.econ.by.party)<-c("cducsu.voter","spd.voter","fdp.voter","greens.voter","linke.voter")
	
	## impact of economic decline for different government supporters (HIGH CONFLICT)
	pp.Hcon.econ.by.party<-cbind(pp.Hcon.cducsu[,"cducsu"],pp.Hcon.spd[,"cducsu"],pp.Hcon.fdp[,"cducsu"],pp.Hcon.greens[,"cducsu"],pp.Hcon.linke[,"cducsu"])
	colnames(pp.Hcon.econ.by.party)<-c("cducsu.voter","spd.voter","fdp.voter","greens.voter","linke.voter")

	
	
####################################################
## policy dissatisfaction (20 policy areas)
####################################################	
	
	
	## 20 policy areas
	res2<-res_pa
	
	
	parties<-c("cducsu","fdp","spd","greens","linke")
	pp.Lcon.cducsu<-NA
	pp.Hcon.cducsu<-NA		
	pp.Lcon.spd <-NA
	pp.Hcon.spd <-NA		
	pp.Lcon.fdp <-NA
	pp.Hcon.fdp <-NA		
	pp.Lcon.greens <-NA
	pp.Hcon.greens <-NA		
	pp.Lcon.linke <-NA
	pp.Hcon.linke <-NA		
	
	
	for(i in 1:5){
	  
	  
	  ## set partisanship
	  party.supporter<-NA
	  party.supporter<-parties[i]
	  
	  
	  
	  ### PP for ECON (cary econ, set conflict to 9)
	  
	  
	  
	  ## High Conflict
	  pa<-seq(0,max(data$policy_discr_all), length.out=50)
	  
	  sim.econ.hcon<-with(mdata,
	                      expand.grid(alt = unique(alt),
	                                  policy_discr_all=pa,
	                                  gov_conflict = 9 ,
	                                  vote_le = 1,
	                                  conflict = mean(conflict), 
	                                  competence=max(competence), 
	                                  age_cat= mean(age_cat),
	                                  woman=0,
	                                  education=mean(education),
	                                  religion_activity=data$religion_activity[1],
	                                  family_satisfaction=mean(family_satisfaction),
	                                  financial_satisfaction=mean(financial_satisfaction),
	                                  leisure_satisfaction=mean(leisure_satisfaction),
	                                  pol_know_all=mean(pol_know_all)                                                                                                
	                      ))
	  sim.econ.hcon$vote_le[sim.econ.hcon$alt!= party.supporter]<-0
	  
	  pp.hcon2<-predict(res2,sim.econ.hcon)
	  
	  
	  ## Low Conflict
	  ## specify X
	  sim.econ.lcon<-sim.econ.hcon
	  sim.econ.lcon$gov_conflict<-4
	  
	  ## get predicted probabilities for X
	  pp.lcon2<-predict(res2, sim.econ.lcon)
	  
	  
	  ## Save info
	  
	  if(party.supporter=="cducsu"){
	    pp.Lcon.cducsu<-pp.lcon2
	    pp.Hcon.cducsu<-pp.hcon2		
	  }
	  
	  if(party.supporter=="spd"){
	    pp.Lcon.spd <-pp.lcon2
	    pp.Hcon.spd <-pp.hcon2		
	  }
	  
	  if(party.supporter=="fdp"){
	    pp.Lcon.fdp <-pp.lcon2
	    pp.Hcon.fdp <-pp.hcon2		
	  }
	  
	  if(party.supporter=="greens" ){
	    pp.Lcon.greens <-pp.lcon2
	    pp.Hcon.greens <-pp.hcon2		
	  }
	  
	  if(party.supporter=="linke"){
	    pp.Lcon.linke <-pp.lcon2
	    pp.Hcon.linke <-pp.hcon2		
	  }
	  
	} # close i loop
	
	
##
	##---------------------------------------------------------------------------------------------------------------------
	## save predicted probabilities to vote for CDU/CSU for different party supporters (CDU/CSU, FDP, SPD, Greens, Linke)
	##---------------------------------------------------------------------------------------------------------------------	
	
	## impact of policy dissatisfaction for different government supporters (LOW CONFLICT)
	pp.Lcon.pa.by.party<-cbind(pp.Lcon.cducsu[,"cducsu"],pp.Lcon.spd[,"cducsu"],pp.Lcon.fdp[,"cducsu"],pp.Lcon.greens[,"cducsu"],pp.Lcon.linke[,"cducsu"])
	colnames(pp.Lcon.pa.by.party)<-c("cducsu.voter","spd.voter","fdp.voter","greens.voter","linke.voter")

	## impact of policy dissatisfaction for different government supporters (HIGH CONFLICT)
	pp.Hcon.pa.by.party<-cbind(pp.Hcon.cducsu[,"cducsu"],pp.Hcon.spd[,"cducsu"],pp.Hcon.fdp[,"cducsu"],pp.Hcon.greens[,"cducsu"],pp.Hcon.linke[,"cducsu"])
	colnames(pp.Hcon.pa.by.party)<-c("cducsu.voter","spd.voter","fdp.voter","greens.voter","linke.voter")

	
	

#######################################	
## PLOT FIGURE B.3 from appendix B
#######################################		
	
				pdf(file="./robustness checks/graphs/FigureB.3_appendix.pdf", bg="transparent",width=6.5, height=7.5)
				par(mfrow=c(2,2))
				par(oma=c(2,2,2,2))
				par(mar=c(5,4,5,1))

	plot(y=c(0,0.5), x=c(0,4), type="n", xlab="Economic Decline", ylab="Predicted CDU/CSU Vote", las=1, main="", cex.main=1,cex.lab=1.1) 
				mtext(text="CDU/CSU  Supporters", side=3, line=0.5, cex=0.9,font=2)
				lines(x= econ,y= pp.Hcon.econ.by.party[,"cducsu.voter"], lwd=2, col="black")
				lines(x= econ,y= pp.Lcon.econ.by.party[,"cducsu.voter"], lwd=2, col="gray")
				legend(1,0.5,col=c("black","grey"), lwd=c(2,2), legend=c("High Conflict","Low Conflict"), cex=0.8)

		
		plot(y=c(0,0.5), x=c(0,4), type="n", xlab="Economic Decline", ylab="Predicted CDU/CSU Vote", las=1, main="", cex.main=1,cex.lab=1.1) 
				mtext(text="SPD Supporters", side=3, line=0.5, cex=0.9,font=2)

				lines(x= econ,y= pp.Hcon.econ.by.party[,"spd.voter"], lwd=2, col="black")
				lines(x= econ,y= pp.Lcon.econ.by.party[,"spd.voter"], lwd=2, col="gray")
				legend(1,0.5,col=c("black","grey"), lwd=c(2,2), legend=c("High Conflict","Low Conflict"), cex=0.8)
				mtext(text="Impact of Economic Decline on CDU/CSU Vote", side=3, line=3.5, outer=F, at=-1.5)
				mtext(text="Impact of Policy Dissatisfaction (20 Policy Areas) on CDU/CSU Vote", side=1, line=6, at=-1.3,outer=F)


				
	xlab<-"Dissatisfaction (20 Policy Areas)"
		plot(y=c(0,0.5), x=c(0,3), type="n", xlab=xlab, ylab="Predicted CDU/CSU Vote", las=1, main="", cex.main=1,cex.lab=1.1) 
				mtext(text="CDU/CSU  Supporters", side=3, line=0.5, cex=0.9,font=2)
				lines(x= pa,y= pp.Hcon.pa.by.party[,"cducsu.voter"], lwd=2, col="black")
				lines(x= pa,y= pp.Lcon.pa.by.party[,"cducsu.voter"], lwd=2, col="gray")
					legend(1,0.5,col=c("black","grey"), lwd=c(2,2), legend=c("High Conflict","Low Conflict"), cex=0.8)

				plot(y=c(0,0.5), x=c(0,3), type="n", xlab= xlab, ylab="Predicted CDU/CSU Vote", las=1, main="", cex.main=1,cex.lab=1.1) 
								mtext(text="SPD Supporters", side=3, line=0.5, cex=0.9,font=2)

				lines(x= pa,y= pp.Hcon.pa.by.party[,"spd.voter"], lwd=2, col="black")
				lines(x= pa,y= pp.Lcon.pa.by.party[,"spd.voter"], lwd=2, col="gray")
					legend(1,0.5,col=c("black","grey"), lwd=c(2,2), legend=c("High Conflict","Low Conflict"), cex=0.8)

	
	dev.off()	
	
	

	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	##---------------------------------------------
	## GET FIGURE B.3 FOR ALL PARTIES
	##---------------------------------------------
	
	pdf(file="./robustness checks/graphs/FigureB.3_appendix_ECON_allparties.pdf", bg="transparent",width=7.3, height=5.3)
	
	par(mfrow=c(2,3))
	par(oma=c(2,2,2,2))
	par(mar=c(4,5,4,1))
	
	plot(y=c(0,0.5), x=c(0,4), type="n", xlab="Economic Decline", ylab="Predicted CDU/CSU Vote", las=1, main="", cex.main=1, cex.lab=1.2) 
	mtext(text="CDU/CSU  Supporters", side=3, line=0.5, cex=0.8,font=2)
	
	lines(x= econ,y= pp.Lcon.econ.by.party[,"cducsu.voter"], lwd=2, col="gray")
	lines(x= econ,y= pp.Hcon.econ.by.party[,"cducsu.voter"], lwd=2, col="black")
	
	plot(y=c(0,1), x=c(0,4), type="n", xlab="Economic Decline", ylab="Predicted CDU/CSU Vote", las=1, main="", cex.main=1, cex.lab=1.2) 
	mtext(text="FDP  Supporters", side=3, line=0.5, cex=0.8,font=2)
	
	lines(x= econ,y= pp.Lcon.econ.by.party[,"fdp.voter"], lwd=2, col="gray")
	lines(x= econ,y= pp.Hcon.econ.by.party[,"fdp.voter"], lwd=2, col="black")
	
	mtext(text="Impact of Economic Decline on CDU/CSU Vote", side=3, line=3.5, outer=F, at=2)
	
	
	
	plot(y=c(0,0.5), x=c(0,4), type="n",xaxt = 'n', yaxt = 'n',bty = 'n', xlab="", ylab="", las=1, main="", cex.main=1) 
	lines(x= econ,y= pp.Lcon.econ.by.party[,"linke.voter"], lwd=2, col="white")
	
	legend(0,0.4,col=c("black","grey"), lwd=c(2,2), legend=c("High Conflict","Low Conflict"), cex=1.2)
	
	
	
	
	plot(y=c(0,0.5), x=c(0,4), type="n", xlab="Economic Decline", ylab="Predicted CDU/CSU Vote", las=1, main="", cex.main=1, cex.lab=1.2) 
	mtext(text="SPD Supporters", side=3, line=0.5, cex=0.8,font=2)
	lines(x= econ,y= pp.Lcon.econ.by.party[,"spd.voter"], lwd=2, col="gray")
	lines(x= econ,y= pp.Hcon.econ.by.party[,"spd.voter"], lwd=2, col="black")
	
	plot(y=c(0,0.5), x=c(0,4), type="n", xlab="Economic Decline", ylab="Predicted CDU/CSU Vote", las=1, main="", cex.main=1, cex.lab=1.2) 
	mtext(text="Greens  Supporters", side=3, line=0.5, cex=0.8,font=2)
	
	lines(x= econ,y= pp.Lcon.econ.by.party[,"greens.voter"], lwd=2, col="gray")
	lines(x= econ,y= pp.Hcon.econ.by.party[,"greens.voter"], lwd=2, col="black")
	
	
	plot(y=c(0,0.5), x=c(0,4), type="n", xlab="Economic Decline", ylab="Predicted CDU/CSU Vote", las=1, main="", cex.main=1, cex.lab=1.2) 
	mtext(text="LINKE Supporters", side=3, line=0.5, cex=0.8,font=2)
	lines(x= econ,y= pp.Lcon.econ.by.party[,"linke.voter"], lwd=2, col="gray")
	lines(x= econ,y= pp.Hcon.econ.by.party[,"linke.voter"], lwd=2, col="black")
	
	
	dev.off()
	
	
	pdf(file="./robustness checks/graphs/FigureB.3_appendix_20Areas_allparties.pdf", bg="transparent",width=7.4, height=5.4)
	par(mfrow=c(2,3))
	par(oma=c(2,2,2,2))
	par(mar=c(4,5,4,1))
	
	xlab<-"Dissatisfaction (20 Policy Areas)"
	plot(y=c(0,0.5), x=c(0,3), type="n", xlab=xlab, ylab="Predicted CDU/CSU Vote", las=1, main="", cex.main=1, cex.lab=1.1) 
	mtext(text="CDU/CSU Supporters", side=3, line=0.5, cex=0.8,font=2)
	lines(x= pa,y= pp.Lcon.pa.by.party[,"cducsu.voter"], lwd=2, col="gray")
	lines(x= pa,y= pp.Hcon.pa.by.party[,"cducsu.voter"], lwd=2, col="black")
	
	plot(y=c(0,1), x=c(0,3), type="n", xlab= xlab, ylab="Predicted CDU/CSU Vote", las=1, main="", cex.main=1, cex.lab=1.1) 
	mtext(text="FDP Supporters", side=3, line=0.5, cex=0.8,font=2)
	lines(x= pa,y= pp.Lcon.pa.by.party[,"fdp.voter"], lwd=2, col="gray")
	lines(x= pa,y= pp.Hcon.pa.by.party[,"fdp.voter"], lwd=2, col="black")
	
	mtext(text="Impact of Policy Dissatisfaction (20 Policy Areas) on CDU/CSU Vote", side=3, line=3.5, outer=F, at=1.5)
	
	plot(y=c(0,0.5), x=c(0,4), type="n",xaxt = 'n', yaxt = 'n',bty = 'n', xlab="", ylab="", las=1, main="", cex.main=1, cex.lab=1.1) 
	mtext(text="", side=3, line=0.5, cex=0.8,font=2)
	lines(x= pa,y= pp.Hcon.pa.by.party[,"linke.voter"], lwd=2, col="white")
	legend(0,0.4,col=c("black","gray"), lwd=c(2,2), legend=c("High Conflict","Low Conflict"), cex=1.2)
	
	
	plot(y=c(0,0.5), x=c(0,3), type="n", xlab= xlab, ylab="Predicted CDU/CSU Vote", las=1, main="", cex.main=1, cex.lab=1.1) 
	mtext(text="SPD Supporters", side=3, line=0.5, cex=0.8,font=2)
	lines(x= pa,y= pp.Lcon.pa.by.party[,"spd.voter"], lwd=2, col="gray")
	lines(x= pa,y= pp.Hcon.pa.by.party[,"spd.voter"], lwd=2, col="black")
	
	plot(y=c(0,0.5), x=c(0,3), type="n", xlab= xlab, ylab="Predicted CDU/CSU Vote", las=1, main="", cex.main=1, cex.lab=1.1) 
	mtext(text="Greens Supporters", side=3, line=0.5, cex=0.8,font=2)
	lines(x= pa,y= pp.Lcon.pa.by.party[,"greens.voter"], lwd=2, col="gray")
	lines(x= pa,y= pp.Hcon.pa.by.party[,"greens.voter"], lwd=2, col="black")
	
	
	plot(y=c(0,0.5), x=c(0,3), type="n", xlab= xlab, ylab="Predicted CDU/CSU Vote", las=1, main="", cex.main=1, cex.lab=1.1) 
	mtext(text="LINKE Supporters", side=3, line=0.5, cex=0.8,font=2)
	lines(x= pa,y= pp.Lcon.pa.by.party[,"linke.voter"], lwd=2, col="gray")
	lines(x= pa,y= pp.Hcon.pa.by.party[,"linke.voter"], lwd=2, col="black")
	dev.off()
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	



	
	
	
	
    
 
    	
    	
    	
    	
        
    
